package gregapi.compat.opencomputers;

import static gregapi.data.CS.F;
import static gregapi.data.CS.SIDE_UNKNOWN;
import static gregapi.data.CS.T;
import gregapi.compat.CompatBase;
import gregapi.computer.IComputerizable;
import gregapi.computer.ITileEntityComputerizable;
import gregapi.tileentity.delegate.DelegatorTileEntity;
import gregapi.util.WD;

import java.util.Arrays;

import li.cil.oc.api.Driver;
import li.cil.oc.api.machine.Arguments;
import li.cil.oc.api.machine.Context;
import li.cil.oc.api.network.ManagedEnvironment;
import li.cil.oc.api.network.ManagedPeripheral;
import li.cil.oc.integration.ManagedTileEntityEnvironment;
import net.minecraft.tileentity.TileEntity;
import net.minecraft.world.World;
import cpw.mods.fml.common.event.FMLInitializationEvent;

@SuppressWarnings("deprecation")
public class CompatOC extends CompatBase implements li.cil.oc.api.driver.Block, ICompatOC {
	@Override
	public void onLoad(FMLInitializationEvent aEvent) {
		Driver.add(this);
	}
	
    @Override
    public ManagedEnvironment createEnvironment(World aWorld, int aX, int aY, int aZ) {
        return new Environment(WD.te(aWorld, aX, aY, aZ, SIDE_UNKNOWN, T));
    }
    
    @Override
    public boolean worksWith(World aWorld, int aX, int aY, int aZ) {
        return WD.te(aWorld, aX, aY, aZ, SIDE_UNKNOWN, F).mTileEntity instanceof ITileEntityComputerizable;
    }
    
    public static class Environment extends ManagedTileEntityEnvironment<ITileEntityComputerizable> implements ManagedPeripheral {
		public final IComputerizable mComputerizable;
		public final String mType;
		public final DelegatorTileEntity<TileEntity> mDelegator;
		
        public Environment(DelegatorTileEntity<TileEntity> aDelegator) {
            super((ITileEntityComputerizable)aDelegator.mTileEntity, ((ITileEntityComputerizable)aDelegator.mTileEntity).getComputerizableName(aDelegator));
            mComputerizable = (ITileEntityComputerizable)aDelegator.mTileEntity;
			mDelegator = aDelegator;
			mType = ((ITileEntityComputerizable)aDelegator.mTileEntity).getComputerizableName(mDelegator);
        }
        
		@Override
		public String[] methods() {
			return mComputerizable.allComputerizableMethods(mDelegator);
		}
		
		@Override
		public Object[] invoke(String aFunction, Context aContext, Arguments aArguments) throws Exception {
			return mComputerizable.callComputerizableMethod(mDelegator, Arrays.asList(methods()).indexOf(aFunction), aArguments.toArray());
		}
		
        /*
        @Callback(value = "call", doc = "Calls a Function in this Block, use without any Parameters to see a List of Functions this can call.", direct = T)
        public Object[] call(Context aContext, Arguments aArguments) {
        	String aFunction = aArguments.count() > 0 ? aArguments.checkString(0) : "";
        	int aFunctionIndex = Arrays.asList(mComputerizable.allComputerizableMethods(mDelegator)).indexOf(aFunction);
        	if (aFunctionIndex < 0) return mComputerizable.allComputerizableMethods(mDelegator);
        	ArrayList<Object> tArguments = new ArrayList<Object>();
        	for (int i = 1, j = aArguments.count(); i < j; i++) tArguments.add(aArguments.checkAny(i));
			return mComputerizable.callComputerizableMethod(mDelegator, aFunctionIndex, tArguments.toArray(ZL_OBJECT));
        }
        
        @Callback(value = "fast", doc = "Calls a Function in this Block much more efficiently, by not parsing the Command String nor offering help when failing. Function Indices won't change in future Versions and are stable.", direct = T)
        public Object[] fast(Context aContext, Arguments aArguments) {
        	ArrayList<Object> tArguments = new ArrayList<Object>();
        	for (int i = 1, j = aArguments.count(); i < j; i++) tArguments.add(aArguments.checkAny(i));
			return mComputerizable.callComputerizableMethod(mDelegator, aArguments.checkInteger(0), tArguments.toArray(ZL_OBJECT));
        }
        
        @Callback(value = "help", doc = "Gives more desciption for a Function in this Block, use without any Parameters to see a List of Functions.", direct = T)
        public Object[] help(Context aContext, Arguments aArguments) {
        	String aFunction = aArguments.count() > 0 ? aArguments.checkString(0) : "";
        	int aFunctionIndex = Arrays.asList(mComputerizable.allComputerizableMethods(mDelegator)).indexOf(aFunction);
        	if (aFunctionIndex < 0) return mComputerizable.allComputerizableMethods(mDelegator);
        	String tHelp = mComputerizable.getComputerizableHelp(mDelegator, aFunctionIndex);
			return new Object[] {(UT.Code.stringValid(aFunction)?tHelp:"HALP! BORKEN!!! SOMEONE FORGOT TO ADD A DESCRIPTION HERE!") + " - Function Index: " + aFunctionIndex};
        }
        
        @Callback(value = "returns", doc = "Gives a description for the Return Types of a Function in this Block, use without any Parameters to see a List of Functions.", direct = T)
        public Object[] returns(Context aContext, Arguments aArguments) {
        	String aFunction = aArguments.count() > 0 ? aArguments.checkString(0) : "";
        	int aFunctionIndex = Arrays.asList(mComputerizable.allComputerizableMethods(mDelegator)).indexOf(aFunction);
        	if (aFunctionIndex < 0) return mComputerizable.allComputerizableMethods(mDelegator);
			return new Object[] {mComputerizable.getComputerizableReturn(mDelegator, aFunctionIndex).getName()};
        }
        
        @Callback(value = "args", doc = "Gives a description for the Argument Types of a Function in this Block, use without any Parameters to see a List of Functions.", direct = T)
        public Object[] args(Context aContext, Arguments aArguments) {
        	String aFunction = aArguments.count() > 0 ? aArguments.checkString(0) : "";
        	int aFunctionIndex = Arrays.asList(mComputerizable.allComputerizableMethods(mDelegator)).indexOf(aFunction);
        	if (aFunctionIndex < 0) return mComputerizable.allComputerizableMethods(mDelegator);
			return new Object[] {mComputerizable.getComputerizableArgs(mDelegator, aFunctionIndex)};
        }
        */
    }
}