package gregapi.cover.covers;

import static gregapi.data.CS.*;
import gregapi.cover.CoverData;
import gregapi.data.CS.SFX;
import gregapi.data.LH;
import gregapi.render.BlockTextureDefault;
import gregapi.render.ITexture;
import gregapi.tileentity.connectors.MultiTileEntityPipeFluid;
import gregapi.tileentity.delegate.DelegatorTileEntity;
import gregapi.util.UT;
import gregapi.util.WD;

import java.util.ArrayList;
import java.util.List;

import net.minecraft.entity.Entity;
import net.minecraft.item.ItemStack;
import net.minecraft.util.AxisAlignedBB;
import net.minecraft.util.ChunkCoordinates;
import net.minecraftforge.fluids.IFluidHandler;
import net.minecraftforge.fluids.IFluidTank;

/**
 * @author Gregorius Techneticies
 */
public class CoverPressureValve extends AbstractCoverAttachment {
	@Override public boolean interceptCoverPlacement(byte aCoverSide, CoverData aData, Entity aPlayer) {return !(aData.mTileEntity instanceof MultiTileEntityPipeFluid) || ((MultiTileEntityPipeFluid)aData.mTileEntity).mTanks.length != 1;}
	
	@Override
	public void onTickPost(byte aSide, CoverData aData, long aTimer, boolean aIsServerSide, boolean aReceivedBlockUpdate, boolean aReceivedInventoryUpdate) {
		if (aIsServerSide && aData.mTileEntity instanceof MultiTileEntityPipeFluid) {
			ChunkCoordinates tCoords = aData.mTileEntity.getCoords();
			if ((SERVER_TIME % 2 == 0) != WD.even(tCoords) && ((MultiTileEntityPipeFluid)aData.mTileEntity).mTanks.length == 1) {
				IFluidTank tTank = ((MultiTileEntityPipeFluid)aData.mTileEntity).mTanks[0];
		    	if (tTank.getFluidAmount() >= tTank.getCapacity()) {
					DelegatorTileEntity<IFluidHandler> tDelegator = aData.mTileEntity.getAdjacentTank(aSide);
					if (tDelegator.mTileEntity != null) {
						UT.Fluids.move(tTank, tDelegator);
					} else if (UT.Fluids.gas(tTank.getFluid()) && !tDelegator.hasCollisionBox()) {
				    	UT.Sounds.send(aData.mTileEntity.getWorld(), SFX.MC_FIZZ, 1.0F, 1.0F, tCoords);
				    	try {for (Entity tEntity : (ArrayList<Entity>)aData.mTileEntity.getWorld().getEntitiesWithinAABB(Entity.class, AxisAlignedBB.getBoundingBox(tCoords.posX-2, tCoords.posY-2, tCoords.posZ-2, tCoords.posX+3, tCoords.posY+3, tCoords.posZ+3))) UT.Entities.applyTemperatureDamage(tEntity, UT.Fluids.temperature(tTank.getFluid()), 2.0F);} catch(Throwable e) {if (D1) e.printStackTrace(ERR);}
				    	tTank.drain(Integer.MAX_VALUE, T);
					}
		    	}
			}
		}
	}
	
	@Override
	public void addToolTips(List aList, ItemStack aStack, boolean aF3_H) {
		super.addToolTips(aList, aStack, aF3_H);
		aList.add(LH.Chat.CYAN + "Releases Fluids when Pipe is full.");
		aList.add(LH.Chat.ORANGE + "Liquids require Tank in front!");
		aList.add(LH.Chat.ORANGE + "Gasses require Air or Tank in front!");
	}
	
	@Override public float[] getCoverBounds(byte aCoverSide, CoverData aData) {return BOXES_VALVES[aCoverSide];}
	@Override public float[] getHolderBounds(byte aCoverSide, CoverData aData) {return BOXES_VALVES[aCoverSide];}
	
	public static final float[][] BOXES_VALVES = new float[][] {{PX_P[ 6], PX_P[ 0], PX_P[ 6], PX_N[ 6], PX_N[ 8], PX_N[ 6]}, {PX_P[ 6], PX_P[ 8], PX_P[ 6], PX_N[ 6], PX_N[ 0], PX_N[ 6]}, {PX_P[ 6], PX_P[ 6], PX_P[ 0], PX_N[ 6], PX_N[ 6], PX_N[ 8]}, {PX_P[ 6], PX_P[ 6], PX_P[ 8], PX_N[ 6], PX_N[ 6], PX_N[ 0]}, {PX_P[ 0], PX_P[ 6], PX_P[ 6], PX_N[ 8], PX_N[ 6], PX_N[ 6]}, {PX_P[ 8], PX_P[ 6], PX_P[ 6], PX_N[ 0], PX_N[ 6], PX_N[ 6]}};
	
	@Override public ITexture getCoverTextureSurface(byte aSide, CoverData aData) {return sTextureFront;}
	@Override public ITexture getCoverTextureAttachment(byte aSide, CoverData aData, byte aTextureSide) {return aSide == aTextureSide ? sTextureFront : null;}
	@Override public ITexture getCoverTextureHolder(byte aSide, CoverData aData, byte aTextureSide) {return aSide == aTextureSide ? null : sTextureSide;}
	
	@Override public boolean isSolid(byte aSide, CoverData aData) {return F;}
	
	public static final ITexture
	sTextureFront = BlockTextureDefault.get("machines/covers/pressurevalve/front"),
	sTextureSide = BlockTextureDefault.get("machines/covers/pressurevalve/side");
}