package gregapi.data;

import static gregapi.data.CS.*;
import static gregapi.data.TD.ItemGenerator.*;
import static gregapi.data.TD.Prefix.*;
import static gregapi.data.TD.Processing.REACTS_WITH_GLASS;
import static gregapi.data.TD.Processing.SMITHABLE;
import static gregapi.data.TD.Properties.*;
import static gregapi.oredict.OreDictMaterialCondition.qualmin;
import gregapi.code.ICondition;
import gregapi.code.ICondition.And;
import gregapi.code.ICondition.Or;
import gregapi.oredict.OreDictListenerItem_Washing;
import gregapi.oredict.OreDictMaterial;
import gregapi.oredict.OreDictPrefix;
import gregapi.util.OM;
import gregapi.util.ST;
import net.minecraft.init.Items;

/**
 * @author Gregorius Techneticies
 * 
 * List of all OreDict Prefixes. The Short Name is for ease of overview and stands for "OrePrefix".
 */
public class OP {
	private static OreDictPrefix create(String aName) {return OreDictPrefix.createPrefix(aName);}
	private static OreDictPrefix unused(String aName) {return OreDictPrefix.createPrefix(aName).add(PREFIX_UNUSED);}
	
	public static final OreDictPrefix
	ore							= create("ore"							).setCategoryName("Ores"							).setLocalItemName(""								, " Ore"							)									.setCondition(ORES)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.TERRA		, 1).setTextureSetName("ore").addIdenticalNames("oreGem"), // Regular Ore Prefix. Ore -> Material is a One-Way Operation! Introduced by Eloraam
	
	oreBedrock					= create("oreBedrock"					).setCategoryName("Bedrock Ores"					).setLocalItemName("Bedrock "						, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.TERRA		,10).setTextureSetName("oreBedrock"),
	oreBlackgranite				= create("oreBlackgranite"				).setCategoryName("Black Granite Ores"				).setLocalItemName("Granite "						, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.TERRA		, 1).setTextureSetName("ore"),
	oreRedgranite				= create("oreRedgranite"				).setCategoryName("Red Granite Ores"				).setLocalItemName("Granite "						, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.TERRA		, 1).setTextureSetName("ore"),
	oreAndesite					= create("oreAndesite"					).setCategoryName("Andesite Ores"					).setLocalItemName("Andesite "						, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.TERRA		, 1).setTextureSetName("ore"),
	oreDiorite					= create("oreDiorite"					).setCategoryName("Diorite Ores"					).setLocalItemName("Diorite "						, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.TERRA		, 1).setTextureSetName("ore"),
	oreMoon						= create("oreMoon"						).setCategoryName("Moon Ores"						).setLocalItemName("Moon "							, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.ALIENIS	, 1).setTextureSetName("ore"),
	oreMars						= create("oreMars"						).setCategoryName("Mars Ores"						).setLocalItemName("Mars "							, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.ALIENIS	, 1).setTextureSetName("ore"),
	oreSpace					= create("oreSpace"						).setCategoryName("Space Ores"						).setLocalItemName("Space "							, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.ALIENIS	, 1).setTextureSetName("ore"),
	oreUmberstone				= create("oreUmberstone"				).setCategoryName("Umberstone Ores"					).setLocalItemName("Umberstone "					, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.BESTIA		, 1).setTextureSetName("ore"),
	oreBasalt					= create("oreBasalt"					).setCategoryName("Basalt Ores"						).setLocalItemName("Basalt "						, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.TERRA		, 1).setTextureSetName("ore"),
	oreMarble					= create("oreMarble"					).setCategoryName("Marble Ores"						).setLocalItemName("Marble "						, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.TERRA		, 1).setTextureSetName("ore"),
	oreLimestone				= create("oreLimestone"					).setCategoryName("Limestone Ores"					).setLocalItemName("Limestone "						, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.TERRA		, 1).setTextureSetName("ore"),
	oreNetherrack				= create("oreNetherrack"				).setCategoryName("Netherrack Ores"					).setLocalItemName("Nether "						, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.IGNIS		, 1).setTextureSetName("ore"),
	oreEndstone					= create("oreEndstone"					).setCategoryName("Endstone Ores"					).setLocalItemName("End "							, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.ALIENIS	, 1).setTextureSetName("ore"),
	oreSandstone				= create("oreSandstone"					).setCategoryName("Sandstone Ores"					).setLocalItemName("Sandstone "						, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.TERRA		, 1).setTextureSetName("ore"),
	oreGravel					= create("oreGravel"					).setCategoryName("Gravel Ores"						).setLocalItemName("Gravel "						, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED, DUST_ORE	).aspects(TC.TERRA		, 1).setTextureSetName("oreDust"),
	oreRedSand					= create("oreRedSand"					).setCategoryName("Red Sand Ores"					).setLocalItemName("Sand "							, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED, DUST_ORE	).aspects(TC.TERRA		, 1).setTextureSetName("oreDust"),
	oreSand						= create("oreSand"						).setCategoryName("Sand Ores"						).setLocalItemName("Sand "							, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED, DUST_ORE	).aspects(TC.TERRA		, 1).setTextureSetName("oreDust"),
	oreMud						= create("oreMud"						).setCategoryName("Mud Ores"						).setLocalItemName("Mud "							, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED, DUST_ORE	).aspects(TC.TERRA		, 1).setTextureSetName("oreDust"),
	
	oreNether					= create("oreNether"					).setCategoryName("Nether Ores"						).setLocalItemName("Nether "						, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED, DENSE_ORE).aspects(TC.TERRA		, 1).setTextureSetName("oreDense"), // Prefix of the Nether-Ores Mod. Causes Ores to double. Ore -> Material is a Oneway Operation!
	oreDense					= create("oreDense"						).setCategoryName("Dense Ores"						).setLocalItemName("Dense "							, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED, DENSE_ORE).aspects(TC.TERRA		, 1).setTextureSetName("oreDense").addIdenticalNames("denseore"), // Prefix of the Dense-Ores Mod. Causes Ores to double. Ore -> Material is a Oneway Operation!
	oreEnd						= create("oreEnd"						).setCategoryName("End Ores"						).setLocalItemName("End "							, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED, DENSE_ORE).aspects(TC.TERRA		, 1).setTextureSetName("oreDense"), // In case of an End-Ores Mod. Ore -> Material is a Oneway Operation!
	
	oreHee						= create("oreHee"						).setCategoryName("Hee Ores"						).setLocalItemName("Hee "							, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.TERRA		, 1),
	
	oreRich						= create("oreRich"						).setCategoryName("Rich Ores"						).setLocalItemName("Rich "							, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.TERRA		, 1), // Prefix of TFC
	oreNormal					= create("oreNormal"					).setCategoryName("Normal Ores"						).setLocalItemName("Normal "						, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.TERRA		, 1), // Prefix of TFC
	oreSmall					= create("oreSmall"						).setCategoryName("Small Ores"						).setLocalItemName("Small "							, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.TERRA		, 1), // Prefix of TFC.
	orePoor						= create("orePoor"						).setCategoryName("Poor Ores"						).setLocalItemName("Poor "							, " Ore"							)									.setCondition(ore)																							.add(UNIFICATABLE, ORE, UNIFICATABLE_RECIPES, MATERIAL_BASED, BLOCK_BASED			).aspects(TC.TERRA		, 1), // Prefix of Railcraft.
	
	crushed						= create("crushed"						).setCategoryName("Crushed Ores"					).setLocalItemName("Crushed "						, " Ore"							)	.setMaterialStats( 9*U8)		.setCondition(ore)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_DIRTY).aspects(TC.PERFODIO, 1),
	crushedTiny					= create("crushedTiny"					).setCategoryName("Tiny Crushed Ores"				).setLocalItemName("Tiny Crushed "					, " Ore"							)	.setMaterialStats( 9*U72)		.setCondition(crushed)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_DIRTY).aspects(TC.PERFODIO, 1),
	crushedPurified				= create("crushedPurified"				).setCategoryName("Purified Ores"					).setLocalItemName("Purified "						, " Ore"							)	.setMaterialStats(10*U8)		.setCondition(ore)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_CLEAN).aspects(TC.PERFODIO, 1),
	crushedPurifiedTiny			= create("crushedPurifiedTiny"			).setCategoryName("Tiny Purified Ores"				).setLocalItemName("Tiny Purified "					, " Ore"							)	.setMaterialStats(10*U72)		.setCondition(crushedPurified)																				.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_CLEAN).aspects(TC.PERFODIO, 1),
	crushedCentrifuged			= create("crushedCentrifuged"			).setCategoryName("Refined Ores"					).setLocalItemName("Refined "						, " Ore"							)	.setMaterialStats(11*U8)		.setCondition(ore)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_REFINED).aspects(TC.PERFODIO, 1),
	crushedCentrifugedTiny		= create("crushedCentrifugedTiny"		).setCategoryName("Tiny Refined Ores"				).setLocalItemName("Tiny Refined "					, " Ore"							)	.setMaterialStats(11*U72)		.setCondition(crushedCentrifuged)																			.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_REFINED).aspects(TC.PERFODIO, 1),
	rockGt						= create("rockGt"						).setCategoryName("Rocks"							).setLocalItemName(""								, " bearing Rock"					)	.setMaterialStats(U4   )		.setCondition(new Or(ore, STONE))																			.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_DIRTY).aspects(TC.TERRA, 1),
	rawOreChunk					= create("rawOreChunk"					).setCategoryName("Raw Ore Chunks"					).setLocalItemName("Raw Chunk of "					, " Ore"							)	.setMaterialStats(27*U72)		.setCondition(ore)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_DIRTY).aspects(TC.TERRA, 1), // Prefix of Harder Ores
	shard						= create("shard"						).setCategoryName("Crystallised Shards"				).setLocalItemName(""								, ""								)	.setMaterialStats(U    )		.setCondition(ore)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_REFINED).aspects(TC.FABRICO, 1), // Introduced by Mekanism
	clump						= create("clump"						).setCategoryName("Clumps"							).setLocalItemName(""								, ""								)	.setMaterialStats(U    )		.setCondition(ore)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_CLEAN).aspects(TC.FABRICO, 1),
	cluster						= create("cluster"						).setCategoryName("Native Clusters"					).setLocalItemName("Native "						, " Cluster"						)	.setMaterialStats(U * 2)		.setCondition(ore)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_DIRTY).aspects(TC.ORDO, 1, TC.TERRA, 1), // Introduced by Thaumcraft
	reduced						= create("reduced"						).setCategoryName("Reduced Gravels"					).setLocalItemName(""								, ""								)	.setMaterialStats(U    )		.setCondition(ore)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_CLEAN).aspects(TC.FABRICO, 1),
//	RoC?						= create("RoC?"							).setCategoryName("Flakes"							).setLocalItemName(""								, ""								)	.setMaterialStats(U    )		.setCondition(ore)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_REFINED).aspects(TC.FABRICO, 1), // Introduced by RotaryCraft
	crystalline					= create("crystalline"					).setCategoryName("Crystallised Metals"				).setLocalItemName(""								, ""								)	.setMaterialStats(U    )		.setCondition(ore)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_REFINED).aspects(TC.FABRICO, 1),
	pebbles						= create("pebbles"						).setCategoryName("Pebbles"							).setLocalItemName(""								, ""								)	.setMaterialStats(U * 2)		.setCondition(ore)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_DIRTY).aspects(TC.FABRICO, 1),
	rubble						= create("rubble"						).setCategoryName("Rubble"							).setLocalItemName(""								, ""								)	.setMaterialStats(U * 2)		.setCondition(ore)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_DIRTY).aspects(TC.FABRICO, 1),
	chunk						= create("chunk"						).setCategoryName("Chunks"							).setLocalItemName(""								, ""								)	.setMaterialStats(U * 2)		.setCondition(ore)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_DIRTY).aspects(TC.FABRICO, 1),
	cleanGravel					= create("cleanGravel"					).setCategoryName("Clean Gravels"					).setLocalItemName(""								, ""								)	.setMaterialStats(U    )		.setCondition(ore)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_CLEAN).aspects(TC.FABRICO, 1),
	dirtyGravel					= create("dirtyGravel"					).setCategoryName("Dirty Gravels"					).setLocalItemName(""								, ""								)	.setMaterialStats(U    )		.setCondition(ore)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_DIRTY).aspects(TC.FABRICO, 1),
	
	dust						= create("dust"							).setCategoryName("Dusts"							).setLocalItemName(""								, " Dust"							)	.setMaterialStats(U    )		.setCondition(new Or(DUSTS, DIRTY_DUSTS))																	.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, DUST_BASED, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.PERDITIO, 1).addIdenticalNames("pulp", "itemDust"), // Pure Dust worth of one Ingot or Gem. Introduced by Alblaka.
	dustSmall					= create("dustSmall"					).setCategoryName("Small Dusts"						).setLocalItemName("Small Pile of "					, " Dust"							)	.setMaterialStats(U4   )		.setCondition(dust)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, DUST_BASED, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize( 4), // 1/4th of a Dust.
	dustTiny					= create("dustTiny"						).setCategoryName("Tiny Dusts"						).setLocalItemName("Tiny Pile of "					, " Dust"							)	.setMaterialStats(U9   )		.setCondition(dust)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, DUST_BASED, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize( 9), // 1/9th of a Dust.
	dustDiv72					= create("dustDiv72"					).setCategoryName("1/72nd Dusts"					).setLocalItemName("1/72nd of a Pile of "			, " Dust"							)	.setMaterialStats(U72  )		.setCondition(dust)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, DUST_BASED, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize( 8), // 1/72nd of a Dust.
	dustImpure					= create("dustImpure"					).setCategoryName("Impure Dusts"					).setLocalItemName("Impure Pile of "				, " Dust"							)	.setMaterialStats(U    )		.setCondition(new Or(ore, DIRTY_DUSTS))																		.add(UNIFICATABLE, BURNABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_DIRTY											).setMinStacksize( 1).aspects(TC.TERRA, 1).addIdenticalNames("dustDirty"), // Dust with impurities. 1 Unit of Main Material and 1/9 - 1/4 Unit of secondary Material
	dustPure					= create("dustPure"						).setCategoryName("Purified Dusts"					).setLocalItemName("Purified Pile of "				, " Dust"							)	.setMaterialStats(U    )		.setCondition(new Or(ore, DIRTY_DUSTS))																		.add(UNIFICATABLE, BURNABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_CLEAN											).setMinStacksize( 1).aspects(TC.AQUA, 1),
	dustRefined					= create("dustRefined"					).setCategoryName("Refined Dusts"					).setLocalItemName("Refined Pile of "				, " Dust"							)	.setMaterialStats(U    )		.setCondition(new Or(ore, DIRTY_DUSTS))																		.add(UNIFICATABLE, BURNABLE, ORE_PROCESSING_BASED, ORE_PROCESSING_REFINED										).setMinStacksize( 1).aspects(TC.FABRICO, 1),
	
	ingotQuintuple				= create("ingotQuintuple"				).setCategoryName("5x Ingots"						).setLocalItemName("Quintuple "						, " Ingot"							)	.setMaterialStats(U * 5)		.setCondition(MULTIINGOTS)																					.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).setMinStacksize( 2).aspects(TC.METALLUM, 3), // A quintuple Ingot.
	ingotQuadruple				= create("ingotQuadruple"				).setCategoryName("4x Ingots"						).setLocalItemName("Quadruple "						, " Ingot"							)	.setMaterialStats(U * 4)		.setCondition(MULTIINGOTS)																					.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).setMinStacksize( 2).aspects(TC.METALLUM, 2).addIdenticalNames("ingotQuad"), // A quadruple Ingot.
	ingotTriple					= create("ingotTriple"					).setCategoryName("3x Ingots"						).setLocalItemName("Triple "						, " Ingot"							)	.setMaterialStats(U * 3)		.setCondition(MULTIINGOTS)																					.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).setMinStacksize( 3).aspects(TC.METALLUM, 2), // A triple Ingot.
	ingotDouble					= create("ingotDouble"					).setCategoryName("2x Ingots"						).setLocalItemName("Double "						, " Ingot"							)	.setMaterialStats(U * 2)		.setCondition(MULTIINGOTS)																					.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).setMinStacksize( 5).aspects(TC.METALLUM, 1), // A double Ingot. Introduced by TerraFirmaCraft
	ingotHot					= create("ingotHot"						).setCategoryName("Hot Ingots"						).setLocalItemName("Hot "							, " Ingot"							)	.setMaterialStats(U    )		.setCondition(INGOTS_HOT)																					.add(UNIFICATABLE, BURNABLE, TOOLTIP_MATERIAL).setMinStacksize( 4).aspects(TC.METALLUM, 1), // A hot Ingot.
	ingot						= create("ingot"						).setCategoryName("Ingots"							).setLocalItemName(""								, " Ingot"							)	.setMaterialStats(U    )		.setCondition(INGOTS)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, INGOT_BASED, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).setMinStacksize(16).aspects(TC.METALLUM, 1), // A regular Ingot. Introduced by Eloraam
	chunkGt						= create("chunkGt"						).setCategoryName("Chunks"							).setLocalItemName(""								, " Chunk"							)	.setMaterialStats(U4   )		.setCondition(ingot)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, INGOT_BASED, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).setMinStacksize( 4).aspects(TC.METALLUM, 1), // A large Nugget.
	nugget						= create("nugget"						).setCategoryName("Nuggets"							).setLocalItemName(""								, " Nugget"							)	.setMaterialStats(U9   )		.setCondition(ingot)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, INGOT_BASED, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).setMinStacksize( 9).aspects(TC.METALLUM, 1), // A Nugget. Introduced by Eloraam
	
	gemChipped					= create("gemChipped"					).setCategoryName("Chipped Gemstones"				).setLocalItemName("Chipped "						, ""								)	.setMaterialStats(U4   )		.setCondition(new And(GEMS, TRANSPARENT, CRYSTAL, PEARL.NOT))												.add(UNIFICATABLE, BURNABLE, SELF_REFERENCING, RECYCLABLE, SIMPLIFIABLE, GEM_BASED, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).aspects(TC.VITREUS, 1), // A regular Gem worth one small Dust. Introduced by TerraFirmaCraft
	gemFlawed					= create("gemFlawed"					).setCategoryName("Flawed Gemstones"				).setLocalItemName("Flawed "						, ""								)	.setMaterialStats(U2   )		.setCondition(new And(GEMS, TRANSPARENT, CRYSTAL, PEARL.NOT))												.add(UNIFICATABLE, BURNABLE, SELF_REFERENCING, RECYCLABLE, SIMPLIFIABLE, GEM_BASED, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).aspects(TC.VITREUS, 1), // A regular Gem worth two small Dusts. Introduced by TerraFirmaCraft
	gemFlawless					= create("gemFlawless"					).setCategoryName("Flawless Gemstones"				).setLocalItemName("Flawless "						, ""								)	.setMaterialStats(U * 2)		.setCondition(new And(GEMS, TRANSPARENT, CRYSTAL, PEARL.NOT))												.add(UNIFICATABLE, BURNABLE, SELF_REFERENCING, RECYCLABLE, SIMPLIFIABLE, GEM_BASED, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).aspects(TC.VITREUS, 2), // A regular Gem worth two Dusts. Introduced by TerraFirmaCraft
	gemExquisite				= create("gemExquisite"					).setCategoryName("Exquisite Gemstones"				).setLocalItemName("Exquisite "						, ""								)	.setMaterialStats(U * 4)		.setCondition(new And(GEMS, TRANSPARENT, CRYSTAL, PEARL.NOT))												.add(UNIFICATABLE, BURNABLE, SELF_REFERENCING, RECYCLABLE, SIMPLIFIABLE, GEM_BASED, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).aspects(TC.VITREUS, 3), // A regular Gem worth four Dusts. Introduced by TerraFirmaCraft
	gemLegendary				= create("gemLegendary"					).setCategoryName("Legendary Gemstones"				).setLocalItemName("Legendary "						, ""								)	.setMaterialStats(U * 8)		.setCondition(new And(GEMS, TRANSPARENT, CRYSTAL, PEARL.NOT))												.add(UNIFICATABLE, BURNABLE, SELF_REFERENCING, RECYCLABLE, SIMPLIFIABLE, GEM_BASED, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).aspects(TC.VITREUS, 4), // A regular Gem worth nine Dusts. Introduced by GregTech
	gem							= create("gem"							).setCategoryName("Gemstones"						).setLocalItemName(""								, ""								)	.setMaterialStats(U    )		.setCondition(GEMS)																							.add(UNIFICATABLE, BURNABLE, SELF_REFERENCING, RECYCLABLE, SIMPLIFIABLE, GEM_BASED, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).setMinStacksize(16).aspects(TC.VITREUS, 1), // A regular Gem worth one Dust. Introduced by Eloraam
	bouleGt						= create("bouleGt"						).setCategoryName("Boules"							).setLocalItemName(""								, " Boule"							)	.setMaterialStats(U * 4)		.setCondition(ICondition.FALSE)																				.add(UNIFICATABLE, BURNABLE, SELF_REFERENCING, RECYCLABLE, SIMPLIFIABLE, GEM_BASED, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).aspects(TC.VITREUS, 1), // A boule which can be used to cut gem stuff out of.
	crystalPure					= create("crystalPure"					).setCategoryName("Pure Crystals"					).setLocalItemName("Pure "							, " Crystal"						)	.setMaterialStats(U2   )		.setCondition(GEMS)																							.add(BURNABLE, RECYCLABLE).aspects(TC.VITREUS, 1),
	crystal						= create("crystal"						).setCategoryName("Crystals"						).setLocalItemName(""								, " Crystal"						)	.setMaterialStats(U    )		.setCondition(GEMS)																							.add(BURNABLE, RECYCLABLE).aspects(TC.VITREUS, 1),
	lens						= create("lens"							).setCategoryName("Lenses"							).setLocalItemName(""								, " Lens"							)	.setMaterialStats(U4* 3)		.setCondition(LENSES)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER).aspects(TC.VITREUS, 1, TC.FABRICO, 1), // 3/4 of a Plate or Gem used to shape a Lense. Normally only used on Transparent Materials.
	
	scrapGt						= create("scrapGt"						).setCategoryName("Scrap"							).setLocalItemName(""								, " Scrap"							)	.setMaterialStats(U9   )		.setCondition(new Or(dust, ingot, gem))																		.add(TD.Creative.HIDDEN, UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).aspects(TC.PERDITIO, 1).setStacksize(18), // A piece of random Scrap. Basically just a container for 1/9th of a Material Unit of anything, which still has to be processed. Usually comes when breaking down Machines.
	
	plateSteamcraft				= create("plateSteamcraft"				).setCategoryName("Steamcraft Plates"				).setLocalItemName(""								, ""								)									.setCondition(PLATES)																						.add(								  																).setMinStacksize(16).aspects(TC.FABRICO, 1),
	plateDense					= create("plateDense"					).setCategoryName("Dense Plates"					).setLocalItemName("Dense "							, " Plate"							)	.setMaterialStats(U * 9)		.setCondition(DENSEPLATES)																					.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 3), // 9 Plates combined in one Item.
	plateQuintuple				= create("plateQuintuple"				).setCategoryName("5x Plates"						).setLocalItemName("Quintuple "						, " Plate"							)	.setMaterialStats(U * 5)		.setCondition(MULTIPLATES)																					.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 2),
	plateQuadruple				= create("plateQuadruple"				).setCategoryName("4x Plates"						).setLocalItemName("Quadruple "						, " Plate"							)	.setMaterialStats(U * 4)		.setCondition(MULTIPLATES)																					.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 2).addIdenticalNames("plateQuad"),
	plateTriple					= create("plateTriple"					).setCategoryName("3x Plates"						).setLocalItemName("Triple "						, " Plate"							)	.setMaterialStats(U * 3)		.setCondition(MULTIPLATES)																					.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1),
	plateDouble					= create("plateDouble"					).setCategoryName("2x Plates"						).setLocalItemName("Double "						, " Plate"							)	.setMaterialStats(U * 2)		.setCondition(MULTIPLATES)																					.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1),
	plate						= create("plate"						).setCategoryName("Plates"							).setLocalItemName(""								, " Plate"							)	.setMaterialStats(U    )		.setCondition(new And(new Or(ingot, gem.NOT), PLATES))														.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1), // Regular Plate made of one Ingot/Dust. Introduced by Calclavia
	plateGem					= create("plateGem"						).setCategoryName("Gem Plates"						).setLocalItemName("Crystalline "					, " Plate"							)	.setMaterialStats(U    )		.setCondition(new And(new Or(gem, bouleGt), PLATES))														.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1), // Regular Plate made of one Gem/Dust.
	plateTiny					= create("plateTiny"					).setCategoryName("Tiny Plates"						).setLocalItemName("Tiny "							, " Plate"							)	.setMaterialStats(U9   )		.setCondition(plate)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1), // Tiny Plate made of one ninth Ingot/Dust.
	plateGemTiny				= create("plateGemTiny"					).setCategoryName("Tiny Gem Plates"					).setLocalItemName("Tiny Crystalline "				, " Plate"							)	.setMaterialStats(U9   )		.setCondition(plateGem)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1), // Tiny Plate made of one ninth Gem/Dust.
	plateCurved					= create("plateCurved"					).setCategoryName("Curved Plates"					).setLocalItemName("Curved "						, " Plate"							)	.setMaterialStats(U    )		.setCondition(plate)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1), // Curved regular Plate.
	compressed					= create("compressed"					).setCategoryName("Compressed Materials"			).setLocalItemName("Compressed "					, ""								)	.setMaterialStats(U    )		.setCondition(PLATES)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1).addIdenticalNames("Compressed"), // Compressed Material, worth 1 Unit. Introduced by Galacticraft
	sheetGt						= create("sheetGt"						).setCategoryName("Flat Sheets"						).setLocalItemName(""								, " Sheet"							)	.setMaterialStats(U    )		.setCondition(PLATES)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1), // Flat Sheet, worth 1 Unit. Introduced by Advanced Rocketry, Prefix Name redirected by GT
	
	foil						= create("foil"							).setCategoryName("Foils"							).setLocalItemName(""								, " Foil"							)	.setMaterialStats(U4   )		.setCondition(FOILS)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1), // Foil made of 1/4 Ingot/Dust.
	stick						= create("stick"						).setCategoryName("Sticks/Rods"						).setLocalItemName(""								, " Rod"							)	.setMaterialStats(U2   )		.setCondition(STICKS)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1), // Stick made of half an Ingot. Introduced by Eloraam
	stickLong					= create("stickLong"					).setCategoryName("Long Sticks/Rods"				).setLocalItemName("Long "							, " Rod"							)	.setMaterialStats(U    )		.setCondition(stick)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1), // Stick made of an Ingot.
	bolt						= create("bolt"							).setCategoryName("Bolts"							).setLocalItemName(""								, " Bolt"							)	.setMaterialStats(U8   )		.setCondition(stick)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1), // consisting out of 1/8 Ingot or 1/4 Stick.
	screw						= create("screw"						).setCategoryName("Screws"							).setLocalItemName(""								, " Screw"							)	.setMaterialStats(U9   )		.setCondition(bolt)																							.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1), // consisting out of a Bolt.
	round						= create("round"						).setCategoryName("Rounds"							).setLocalItemName(""								, " Round"							)	.setMaterialStats(U9   )		.setCondition(PARTS)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1), // consisting out of one Nugget.
	ring						= create("ring"							).setCategoryName("Rings"							).setLocalItemName(""								, " Ring"							)	.setMaterialStats(U4   )		.setCondition(PARTS)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1), // consisting out of 1/2 Stick.
	spring						= create("spring"						).setCategoryName("Springs"							).setLocalItemName(""								, " Spring"							)	.setMaterialStats(U    )		.setCondition(new And(PARTS, new Or(STRETCHY, BOUNCY, BRITTLE.NOT)))										.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.MOTUS, 1), // consisting out of 2 Sticks.
	springSmall					= create("springSmall"					).setCategoryName("Small Springs"					).setLocalItemName("Small "							, " Spring"							)	.setMaterialStats(U4   )		.setCondition(spring)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.MOTUS, 1), // consisting out of 1 Fine Wire.
	wireFine					= create("wireFine"						).setCategoryName("Fine Wires"						).setLocalItemName("Fine "							, " Wire"							)	.setMaterialStats(U8   )		.setCondition(new Or(WIRES, new And(PARTS, SMITHABLE)))														.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1), // consisting out of 1/8 Ingot or 1/4 Wire.
	minecartWheels				= create("minecartWheels"				).setCategoryName("Cart Wheels"						).setLocalItemName(""								, " Cart Wheels"					)	.setMaterialStats(U    )		.setCondition(new And(PARTS, SMITHABLE))																	.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1, TC.ITER, 1).setStacksize(16), // consisting out of 2 Rings and 1 Rod.
	gearGt						= create("gearGt"						).setCategoryName("Gears"							).setLocalItemName(""								, " Gear"							)	.setMaterialStats(U * 4)		.setCondition(PARTS)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.MOTUS, 1, TC.MACHINA, 1), // Introduced by me because BuildCraft has ruined the gear Prefix...
	gearGtSmall					= create("gearGtSmall"					).setCategoryName("Small Gears"						).setLocalItemName("Small "							, " Gear"							)	.setMaterialStats(U    )		.setCondition(gearGt)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.MOTUS, 1, TC.MACHINA, 1),
	railGt						= create("railGt"						).setCategoryName("Single Rails"					).setLocalItemName(""								, " Rail"							)	.setMaterialStats(U4   )		.setCondition(RAILS)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.ITER, 1),
	casingSmall					= create("casingSmall"					).setCategoryName("Item Casings"					).setLocalItemName(""								, " Item Casing"					)	.setMaterialStats(U2   )		.setCondition(PARTS)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize(16).aspects(TC.FABRICO, 1), // consisting out of half a Metal Plate
	casingMachine				= create("casingMachine"				).setCategoryName("Machine Casings"					).setLocalItemName(""								, " Machine Casing"					)	.setMaterialStats(U * 8)		.setCondition(new And(PARTS, SMITHABLE))																	.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize( 1).aspects(TC.FABRICO, 2, TC.MACHINA, 2).setStacksize(8),
	casingMachineDouble			= create("casingMachineDouble"			).setCategoryName("Robust Machine Casings"			).setLocalItemName("Robust "						, " Machine Casing"					)	.setMaterialStats(U *14)		.setCondition(casingMachine)																				.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize( 1).aspects(TC.FABRICO, 3, TC.MACHINA, 3).setStacksize(4),
	casingMachineQuadruple		= create("casingMachineQuadruple"		).setCategoryName("Reinforced Machine Casings"		).setLocalItemName("Reinforced "					, " Machine Casing"					)	.setMaterialStats(U *26)		.setCondition(casingMachine)																				.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize( 1).aspects(TC.FABRICO, 4, TC.MACHINA, 4).setStacksize(2),
	casingMachineDense			= create("casingMachineDense"			).setCategoryName("Dense Machine Casings"			).setLocalItemName("Dense "							, " Machine Casing"					)	.setMaterialStats(U *56)		.setCondition(casingMachine)																				.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL	).setMinStacksize( 1).aspects(TC.FABRICO, 5, TC.MACHINA, 5).setStacksize(1),
	rotor						= create("rotor"						).setCategoryName("Rotors"							).setLocalItemName(""								, " Rotor"							)	.setMaterialStats(U*4+U4)		.setCondition(PARTS)																						.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, TOOLTIP_MATERIAL					).setMinStacksize(16).aspects(TC.MOTUS, 1, TC.MACHINA, 1).setStacksize(16), // consisting out of 4 Plates, 1 Ring.
	
	chemtube					= create("chemtube"						).setCategoryName("Glass Tubes"						).setLocalItemName("Glass Tube containing "			, ""								)	.setMaterialStats(U9   )		.setCondition(REACTS_WITH_GLASS.NOT)																		.add(UNIFICATABLE, IS_CONTAINER, SELF_REFERENCING, RECYCLABLE, SCANNABLE, TOOLTIP_MATERIAL).setMinStacksize(64),
	cell						= create("cell"							).setCategoryName("Cells"							).setLocalItemName(""								, " Cell"							)									.setCondition(new Or(CONTAINERS, EMPTY, CONTAINERS_FLUID, CONTAINERS_GAS))									.add(UNIFICATABLE, IS_CONTAINER, SELF_REFERENCING, MATERIAL_BASED, RECYCLABLE).setMinStacksize(16), // Regular Gas/Fluid Cell. Introduced by Calclavia
	bucket						= create("bucket"						).setCategoryName("Buckets"							).setLocalItemName(""								, " Bucket"							)									.setCondition(new Or(CONTAINERS, EMPTY, CONTAINERS_FLUID))													.add(IS_CONTAINER, SELF_REFERENCING).setStacksize(16), // A Bucket filled with the Material.
	bottle						= create("bottle"						).setCategoryName("Bottles"							).setLocalItemName(""								, " Bottle"							)									.setCondition(new Or(CONTAINERS, EMPTY, CONTAINERS_FLUID))													.add(IS_CONTAINER, SELF_REFERENCING, MATERIAL_BASED).setStacksize(16), // Glass Bottle containing a Fluid.
	capsule						= create("capsule"						).setCategoryName("Capsules"						).setLocalItemName(""								, " Capsule"						)									.setCondition(new Or(CONTAINERS, EMPTY, CONTAINERS_FLUID, CONTAINERS_GAS))									.add(IS_CONTAINER, SELF_REFERENCING, MATERIAL_BASED).setStacksize(16),
	
	toolHeadSaw					= create("toolHeadSaw"					).setCategoryName("Saw Blades"						).setLocalItemName(""								, " Saw Blade"						)	.setMaterialStats(U * 2 -U9)	.setCondition(new And(TOOLS, HAS_TOOL_STATS, NO_ADVANCED_TOOLS.NOT, BOUNCY.NOT, STRETCHY.NOT, WOOD.NOT))	.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_HANDLE						).setStacksize(16).aspects(TC.INSTRUMENTUM, 2, TC.FABRICO, 1),
	toolHeadFile				= create("toolHeadFile"					).setCategoryName("File Heads"						).setLocalItemName(""								, " File Head"						)	.setMaterialStats(3 *U2)		.setCondition(new And(TOOLS, HAS_TOOL_STATS, NO_ADVANCED_TOOLS.NOT, BOUNCY.NOT, STRETCHY.NOT, WOOD.NOT))	.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_HANDLE						).setStacksize(16).aspects(TC.INSTRUMENTUM, 2, TC.FABRICO, 1),
	toolHeadChisel				= create("toolHeadChisel"				).setCategoryName("Chisel Heads"					).setLocalItemName(""								, " Chisel Head"					)	.setMaterialStats(3 *U2 -U9)	.setCondition(new And(TOOLS, HAS_TOOL_STATS, NO_ADVANCED_TOOLS.NOT, BOUNCY.NOT, STRETCHY.NOT, WOOD.NOT))	.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_HANDLE						).setStacksize(16).aspects(TC.INSTRUMENTUM, 2, TC.FABRICO, 1),
	toolHeadBuzzSaw				= create("toolHeadBuzzSaw"				).setCategoryName("Buzzsaw Blades"					).setLocalItemName(""								, " Buzzsaw Blade"					)	.setMaterialStats(U * 4)		.setCondition(new And(TOOLS, HAS_TOOL_STATS, NO_ADVANCED_TOOLS.NOT, BOUNCY.NOT, STRETCHY.NOT, WOOD.NOT))	.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD									).setStacksize(16).aspects(TC.INSTRUMENTUM, 2, TC.MACHINA, 1, TC.FABRICO, 1),
	toolHeadChainsaw			= create("toolHeadChainsaw"				).setCategoryName("Chainsaw Tips"					).setLocalItemName(""								, " Chainsaw Tip"					)	.setMaterialStats(U * 2)		.setCondition(new And(TOOLS, HAS_TOOL_STATS, NO_ADVANCED_TOOLS.NOT, BOUNCY.NOT, STRETCHY.NOT, WOOD.NOT))	.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD									).setStacksize(16).aspects(TC.INSTRUMENTUM, 2, TC.MACHINA, 1, TC.TELUM, 1),
	toolHeadWrench				= create("toolHeadWrench"				).setCategoryName("Wrench Tips"						).setLocalItemName(""								, " Wrench Tip"						)	.setMaterialStats(U * 4)		.setCondition(new And(TOOLS, HAS_TOOL_STATS, NO_ADVANCED_TOOLS.NOT, BOUNCY.NOT, STRETCHY.NOT, WOOD.NOT))	.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD									).setStacksize(16).aspects(TC.INSTRUMENTUM, 2, TC.MACHINA, 2),
	toolHeadDrill				= create("toolHeadDrill"				).setCategoryName("Drill Tips"						).setLocalItemName(""								, " Drill Tip"						)	.setMaterialStats(U * 4)		.setCondition(new And(TOOLS, HAS_TOOL_STATS, NO_ADVANCED_TOOLS.NOT, BOUNCY.NOT, STRETCHY.NOT, WOOD.NOT))	.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD									).setStacksize(16).aspects(TC.INSTRUMENTUM, 1, TC.MACHINA, 1, TC.PERFODIO, 1),
	toolHeadSword				= create("toolHeadSword"				).setCategoryName("Sword Blades"					).setLocalItemName(""								, " Sword Blade"					)	.setMaterialStats(U * 2 -U9)	.setCondition(new And(WEAPONS, HAS_TOOL_STATS))																.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_HANDLE						).setStacksize(16).aspects(TC.INSTRUMENTUM, 1, TC.TELUM, 2),
	toolHeadPickaxe				= create("toolHeadPickaxe"				).setCategoryName("Pickaxe Heads"					).setLocalItemName(""								, " Pickaxe Head"					)	.setMaterialStats(U * 3 -U9)	.setCondition(new And(TOOLS, HAS_TOOL_STATS))																.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_HANDLE						).setStacksize(16).aspects(TC.INSTRUMENTUM, 2, TC.PERFODIO, 1),
	toolHeadShovel				= create("toolHeadShovel"				).setCategoryName("Shovel Heads"					).setLocalItemName(""								, " Shovel Head"					)	.setMaterialStats(U     -U9)	.setCondition(new And(TOOLS, HAS_TOOL_STATS))																.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_HANDLE						).setStacksize(16).aspects(TC.INSTRUMENTUM, 1),
	toolHeadSpade				= create("toolHeadSpade"				).setCategoryName("Spade Heads"						).setLocalItemName(""								, " Spade Head"						)	.setMaterialStats(U     -U9)	.setCondition(new And(TOOLS, HAS_TOOL_STATS))																.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_HANDLE						).setStacksize(16).aspects(TC.INSTRUMENTUM, 1),
	toolHeadAxe					= create("toolHeadAxe"					).setCategoryName("Axe Heads"						).setLocalItemName(""								, " Axe Head"						)	.setMaterialStats(U * 3 -U9)	.setCondition(new And(TOOLS, HAS_TOOL_STATS))																.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_HANDLE						).setStacksize(16).aspects(TC.INSTRUMENTUM, 2, TC.TELUM, 1),
	toolHeadHoe					= create("toolHeadHoe"					).setCategoryName("Hoe Heads"						).setLocalItemName(""								, " Hoe Head"						)	.setMaterialStats(U * 2 -U9)	.setCondition(new And(TOOLS, HAS_TOOL_STATS))																.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_HANDLE						).setStacksize(16).aspects(TC.INSTRUMENTUM, 2, TC.MESSIS, 1),
	toolHeadSense				= create("toolHeadSense"				).setCategoryName("Sense Blades"					).setLocalItemName(""								, " Sense Blade"					)	.setMaterialStats(U * 3 -U9)	.setCondition(new And(TOOLS, HAS_TOOL_STATS, NO_ADVANCED_TOOLS.NOT))										.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_HANDLE						).setStacksize(16).aspects(TC.INSTRUMENTUM, 2, TC.METO, 1),
	toolHeadPlow				= create("toolHeadPlow"					).setCategoryName("Plow Heads"						).setLocalItemName(""								, " Plow Head"						)	.setMaterialStats(U * 4 -U9)	.setCondition(new And(TOOLS, HAS_TOOL_STATS))																.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_HANDLE						).setStacksize(16).aspects(TC.INSTRUMENTUM, 2, TC.GELUM, 1),
	toolHeadHammer				= create("toolHeadHammer"				).setCategoryName("Hammer Heads"					).setLocalItemName(""								, " Hammer Head"					)	.setMaterialStats(U * 6)		.setCondition(new And(TOOLS, HAS_TOOL_STATS, new Or(BOUNCY, STRETCHY, WOOD, qualmin(1))))					.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_HANDLE						).setStacksize(16).aspects(TC.INSTRUMENTUM, 2, TC.FABRICO, 1),
	toolHeadScrewdriver			= create("toolHeadScrewdriver"			).setCategoryName("Screwdriver Tips"				).setLocalItemName(""								, " Screwdriver Tip"				)	.setMaterialStats(U    )		.setCondition(new And(TOOLS, HAS_TOOL_STATS, NO_ADVANCED_TOOLS.NOT))										.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_HANDLE						).setStacksize(16).aspects(TC.INSTRUMENTUM, 1, TC.MOTUS, 1),
	toolHeadConstructionPickaxe	= create("toolHeadConstructionPickaxe"	).setCategoryName("Construction Pickaxe Heads"		).setLocalItemName(""								, " Construction Pickaxe Head"		)	.setMaterialStats(U * 3 -U9)	.setCondition(new And(toolHeadPickaxe, NO_ADVANCED_TOOLS.NOT))												.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_HANDLE						).setStacksize(16).aspects(TC.INSTRUMENTUM, 2, TC.PERFODIO, 1),
	toolHeadPickaxeGem			= create("toolHeadPickaxeGem"			).setCategoryName("Gem tipped Pickaxe Heads"		).setLocalItemName(""								, " tipped Pickaxe Head"			)	.setMaterialStats(U * 1)		.setCondition(new And(toolHeadPickaxe, gemFlawed, NO_ADVANCED_TOOLS.NOT))									.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_HANDLE						).setStacksize(16).aspects(TC.INSTRUMENTUM, 2, TC.PERFODIO, 1, TC.VITREUS, 1),
	toolHeadAxeDouble			= create("toolHeadAxeDouble"			).setCategoryName("Double Axe Heads"				).setLocalItemName(""								, " Double Axe Head"				)	.setMaterialStats(U*5-2 *U9)	.setCondition(new And(toolHeadAxe, NO_ADVANCED_TOOLS.NOT))													.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_HANDLE						).setStacksize(16).aspects(TC.INSTRUMENTUM, 3, TC.TELUM, 1),
	toolHeadUniversalSpade		= create("toolHeadUniversalSpade"		).setCategoryName("Universal Spade Heads"			).setLocalItemName(""								, " Universal Spade Head"			)	.setMaterialStats(U  -2 *U9)	.setCondition(new And(toolHeadShovel, toolHeadSaw))															.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD									).setStacksize(16).aspects(TC.INSTRUMENTUM, 1, TC.TELUM, 1),
	toolHeadArrow				= create("toolHeadArrow"				).setCategoryName("Arrow Heads"						).setLocalItemName(""								, " Arrow Head"						)	.setMaterialStats(2 *U9)		.setCondition(new And(PROJECTILES, HAS_TOOL_STATS))															.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD									).setStacksize(64).aspects(TC.TELUM, 1),
	
	toolHeadRawSaw				= create("toolHeadRawSaw"				).setCategoryName("Raw Saw Blades"					).setLocalItemName("Raw "							, " Saw Blade"						)	.setMaterialStats(U * 2)		.setCondition(toolHeadSaw)																					.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_SHARPENING, NEEDS_HANDLE	).setStacksize(16, 2).aspects(TC.INSTRUMENTUM, 2, TC.FABRICO, 1),
	toolHeadRawChisel			= create("toolHeadRawChisel"			).setCategoryName("Raw Chisel Heads"				).setLocalItemName("Raw "							, " Chisel Head"					)	.setMaterialStats(3 *U2)		.setCondition(toolHeadChisel)																				.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_SHARPENING, NEEDS_HANDLE	).setStacksize(16, 2).aspects(TC.INSTRUMENTUM, 2, TC.FABRICO, 1),
	toolHeadRawSword			= create("toolHeadRawSword"				).setCategoryName("Raw Sword Blades"				).setLocalItemName("Raw "							, " Sword Blade"					)	.setMaterialStats(U * 2)		.setCondition(toolHeadSword)																				.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_SHARPENING, NEEDS_HANDLE	).setStacksize(16, 2).aspects(TC.INSTRUMENTUM, 1, TC.TELUM, 2),
	toolHeadRawPickaxe			= create("toolHeadRawPickaxe"			).setCategoryName("Raw Pickaxe Heads"				).setLocalItemName("Raw "							, " Pickaxe Head"					)	.setMaterialStats(U * 3)		.setCondition(toolHeadPickaxe)																				.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_SHARPENING, NEEDS_HANDLE	).setStacksize(16, 2).aspects(TC.INSTRUMENTUM, 2, TC.PERFODIO, 1),
	toolHeadRawShovel			= create("toolHeadRawShovel"			).setCategoryName("Raw Shovel Heads"				).setLocalItemName("Raw "							, " Shovel Head"					)	.setMaterialStats(U    )		.setCondition(toolHeadShovel)																				.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_SHARPENING, NEEDS_HANDLE	).setStacksize(16, 2).aspects(TC.INSTRUMENTUM, 1),
	toolHeadRawSpade			= create("toolHeadRawSpade"				).setCategoryName("Raw Spade Heads"					).setLocalItemName("Raw "							, " Spade Head"						)	.setMaterialStats(U    )		.setCondition(toolHeadSpade)																				.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_SHARPENING, NEEDS_HANDLE	).setStacksize(16, 2).aspects(TC.INSTRUMENTUM, 1),
	toolHeadRawUniversalSpade	= create("toolHeadRawUniversalSpade"	).setCategoryName("Raw Universal Spade Heads"		).setLocalItemName("Raw "							, " Universal Spade Head"			)	.setMaterialStats(U     -U9)	.setCondition(toolHeadUniversalSpade)																		.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_SHARPENING, NEEDS_HANDLE	).setStacksize(16, 2).aspects(TC.INSTRUMENTUM, 1, TC.TELUM, 1),
	toolHeadRawAxe				= create("toolHeadRawAxe"				).setCategoryName("Raw Axe Heads"					).setLocalItemName("Raw "							, " Axe Head"						)	.setMaterialStats(U * 3)		.setCondition(toolHeadAxe)																					.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_SHARPENING, NEEDS_HANDLE	).setStacksize(16, 2).aspects(TC.INSTRUMENTUM, 2, TC.TELUM, 1),
	toolHeadRawAxeDouble		= create("toolHeadRawAxeDouble"			).setCategoryName("Raw Double Axe Heads"			).setLocalItemName("Raw "							, " Double Axe Head"				)	.setMaterialStats(U * 5)		.setCondition(toolHeadAxeDouble)																			.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_SHARPENING, NEEDS_HANDLE	).setStacksize(16, 2).aspects(TC.INSTRUMENTUM, 3, TC.TELUM, 1),
	toolHeadRawHoe				= create("toolHeadRawHoe"				).setCategoryName("Raw Hoe Heads"					).setLocalItemName("Raw "							, " Hoe Head"						)	.setMaterialStats(U * 2)		.setCondition(toolHeadHoe)																					.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_SHARPENING, NEEDS_HANDLE	).setStacksize(16, 2).aspects(TC.INSTRUMENTUM, 2, TC.MESSIS, 1),
	toolHeadRawSense			= create("toolHeadRawSense"				).setCategoryName("Raw Sense Blades"				).setLocalItemName("Raw "							, " Sense Blade"					)	.setMaterialStats(U * 3)		.setCondition(toolHeadSense)																				.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_SHARPENING, NEEDS_HANDLE	).setStacksize(16, 2).aspects(TC.INSTRUMENTUM, 2, TC.METO, 1),
	toolHeadRawPlow				= create("toolHeadRawPlow"				).setCategoryName("Raw Plow Heads"					).setLocalItemName("Raw "							, " Plow Head"						)	.setMaterialStats(U * 4)		.setCondition(toolHeadPlow)																					.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_SHARPENING, NEEDS_HANDLE	).setStacksize(16, 2).aspects(TC.INSTRUMENTUM, 2, TC.GELUM, 1),
	toolHeadRawArrow			= create("toolHeadRawArrow"				).setCategoryName("Raw Arrow Heads"					).setLocalItemName("Raw "							, " Arrow Head"						)	.setMaterialStats(U4   )		.setCondition(toolHeadArrow)																				.add(UNIFICATABLE, BURNABLE, RECYCLABLE, SCANNABLE, TOOL_HEAD, NEEDS_SHARPENING					).setStacksize(64, 2).aspects(TC.TELUM, 1),
	
	toolSword					= create("toolSword"					).setCategoryName("Swords"							).setLocalItemName(""								, ""								)	.setMaterialStats(U * 2)		.setCondition(new And(WEAPONS, HAS_TOOL_STATS))																.add(TOOL_ALIKE, BURNABLE, RECYCLABLE, WEAPON_ALIKE	).setStacksize( 1).aspects(TC.INSTRUMENTUM, 1, TC.TELUM, 2), // vanilly Sword
	toolPickaxe					= create("toolPickaxe"					).setCategoryName("Pickaxes"						).setLocalItemName(""								, ""								)	.setMaterialStats(U * 3)		.setCondition(new And(TOOLS, HAS_TOOL_STATS))																.add(TOOL_ALIKE, BURNABLE, RECYCLABLE				).setStacksize( 1).aspects(TC.INSTRUMENTUM, 2, TC.PERFODIO, 1), // vanilly Pickaxe
	toolShovel					= create("toolShovel"					).setCategoryName("Shovels"							).setLocalItemName(""								, ""								)	.setMaterialStats(U    )		.setCondition(new And(TOOLS, HAS_TOOL_STATS))																.add(TOOL_ALIKE, BURNABLE, RECYCLABLE				).setStacksize( 1).aspects(TC.INSTRUMENTUM, 1, TC.TERRA, 1), // vanilly Shovel
	toolAxe						= create("toolAxe"						).setCategoryName("Axes"							).setLocalItemName(""								, ""								)	.setMaterialStats(U * 3)		.setCondition(new And(TOOLS, HAS_TOOL_STATS))																.add(TOOL_ALIKE, BURNABLE, RECYCLABLE, WEAPON_ALIKE	).setStacksize( 1).aspects(TC.INSTRUMENTUM, 2, TC.TELUM, 1), // vanilly Axe
	toolHoe						= create("toolHoe"						).setCategoryName("Hoes"							).setLocalItemName(""								, ""								)	.setMaterialStats(U * 2)		.setCondition(new And(TOOLS, HAS_TOOL_STATS))																.add(TOOL_ALIKE, BURNABLE, RECYCLABLE				).setStacksize( 1).aspects(TC.INSTRUMENTUM, 2, TC.MESSIS, 1), // vanilly Hoe
	toolShears					= create("toolShears"					).setCategoryName("Shears"							).setLocalItemName(""								, ""								)	.setMaterialStats(U * 2)		.setCondition(new And(TOOLS, HAS_TOOL_STATS))																.add(TOOL_ALIKE, BURNABLE, RECYCLABLE				).setStacksize( 1).aspects(TC.INSTRUMENTUM, 2, TC.PANNUS, 1), // vanilly Shears
	tool						= create("tool"							).setCategoryName("Tools"							).setLocalItemName(""								, ""								)									.setCondition(new And(TOOLS, HAS_TOOL_STATS))																.add(TOOL_ALIKE										).setStacksize( 1).aspects(TC.INSTRUMENTUM, 2), // toolPot, toolSkillet, toolSaucepan, toolBakeware, toolCuttingboard, toolMortarandpestle, toolMixingbowl, toolJuicer
	
	bulletGtSmall				= create("bulletGtSmall"				).setCategoryName("Small Bullets"					).setLocalItemName("Small "							, " Bullet"							)	.setMaterialStats(U9   )		.setCondition(new Or(new And(PROJECTILES, HAS_TOOL_STATS), EMPTY))											.add(UNIFICATABLE, BURNABLE, AMMO_ALIKE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE					).aspects(TC.MOTUS, 1, TC.TELUM, 1),
	bulletGtMedium				= create("bulletGtMedium"				).setCategoryName("Medium Bullets"					).setLocalItemName("Medium "						, " Bullet"							)	.setMaterialStats(U6   )		.setCondition(new Or(new And(PROJECTILES, HAS_TOOL_STATS), EMPTY))											.add(UNIFICATABLE, BURNABLE, AMMO_ALIKE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE					).aspects(TC.MOTUS, 1, TC.TELUM, 1),
	bulletGtLarge				= create("bulletGtLarge"				).setCategoryName("Large Bullets"					).setLocalItemName("Large "							, " Bullet"							)	.setMaterialStats(U3   )		.setCondition(new Or(new And(PROJECTILES, HAS_TOOL_STATS), EMPTY))											.add(UNIFICATABLE, BURNABLE, AMMO_ALIKE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE					).aspects(TC.MOTUS, 1, TC.TELUM, 1),
	arrowGtWood					= create("arrowGtWood"					).setCategoryName("Regular Arrows"					).setLocalItemName(""								, " Arrow"							)	.setMaterialStats(2 *U9)		.setCondition(toolHeadArrow)																				.add(UNIFICATABLE, BURNABLE, AMMO_ALIKE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, WEAPON_ALIKE	).aspects(TC.TELUM, 1), // Arrow made of 1/4 Ingot/Dust + Wooden Stick.
	arrowGtPlastic				= create("arrowGtPlastic"				).setCategoryName("Light Arrows"					).setLocalItemName("Light "							, " Arrow"							)	.setMaterialStats(2 *U9)		.setCondition(toolHeadArrow)																				.add(UNIFICATABLE, BURNABLE, AMMO_ALIKE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, WEAPON_ALIKE	).aspects(TC.TELUM, 1), // Arrow made of 1/4 Ingot/Dust + Plastic Stick.
	arrow						= create("arrow"						).setCategoryName("Arrows"							).setLocalItemName(""								, ""								)									.setCondition(toolHeadArrow)																				.add(AMMO_ALIKE, SELF_REFERENCING, WEAPON_ALIKE															).aspects(TC.TELUM, 1),
	
	armorHelmet					= create("armorHelmet"					).setCategoryName("Helmets"							).setLocalItemName(""								, ""								)	.setMaterialStats(U * 5)		.setCondition(ARMORS)																						.add(ARMOR_ALIKE, BURNABLE, RECYCLABLE				).setStacksize( 1).aspects(TC.TUTAMEN, 2), // vanilly Helmet
	armorChestplate				= create("armorChestplate"				).setCategoryName("Chestplates"						).setLocalItemName(""								, ""								)	.setMaterialStats(U * 8)		.setCondition(ARMORS)																						.add(ARMOR_ALIKE, BURNABLE, RECYCLABLE				).setStacksize( 1).aspects(TC.TUTAMEN, 4), // vanilly Chestplate
	armorLeggings				= create("armorLeggings"				).setCategoryName("Leggings"						).setLocalItemName(""								, ""								)	.setMaterialStats(U * 7)		.setCondition(ARMORS)																						.add(ARMOR_ALIKE, BURNABLE, RECYCLABLE				).setStacksize( 1).aspects(TC.TUTAMEN, 3), // vanilly Pants
	armorBoots					= create("armorBoots"					).setCategoryName("Boots"							).setLocalItemName(""								, ""								)	.setMaterialStats(U * 4)		.setCondition(ARMORS)																						.add(ARMOR_ALIKE, BURNABLE, RECYCLABLE				).setStacksize( 1).aspects(TC.TUTAMEN, 2), // vanilly Boots
	armor						= create("armor"						).setCategoryName("Armor Parts"						).setLocalItemName(""								, ""								)									.setCondition(ARMORS)																						.add(ARMOR_ALIKE									).setStacksize( 1).aspects(TC.TUTAMEN, 2),
	
	frameGt						= create("frameGt"						).setCategoryName("Frame Boxes"						).setLocalItemName(""								, ""								)	.setMaterialStats(U * 2)		.setCondition(stick)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER).aspects(TC.FABRICO, 1),
	
	capcellcon					= create("capcellcon"					).setCategoryName("Capsule Cell Containers"			).setLocalItemName(""								, " Capsule Cell Container"			)	.setMaterialStats(U    )		.setCondition(PIPES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER).aspects(TC.VACUOS, 1),
	
	pipeTiny					= create("pipeTiny"						).setCategoryName("Tiny Pipes"						).setLocalItemName("Tiny "							, " Pipe"							)	.setMaterialStats(U2   )		.setCondition(PIPES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER).aspects(TC.ITER, 1),
	pipeSmall					= create("pipeSmall"					).setCategoryName("Small Pipes"						).setLocalItemName("Small "							, " Pipe"							)	.setMaterialStats(U    )		.setCondition(PIPES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER).aspects(TC.ITER, 1),
	pipeMedium					= create("pipeMedium"					).setCategoryName("Medium Pipes"					).setLocalItemName("Medium "						, " Pipe"							)	.setMaterialStats(U * 3)		.setCondition(PIPES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER).aspects(TC.ITER, 1),
	pipeLarge					= create("pipeLarge"					).setCategoryName("Large pipes"						).setLocalItemName("Large "							, " Pipe"							)	.setMaterialStats(U * 6)		.setCondition(PIPES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER).aspects(TC.ITER, 1),
	pipeHuge					= create("pipeHuge"						).setCategoryName("Huge Pipes"						).setLocalItemName("Huge "							, " Pipe"							)	.setMaterialStats(U *12)		.setCondition(PIPES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER).aspects(TC.ITER, 2),
	pipeQuadruple				= create("pipeQuadruple"				).setCategoryName("Quadruple Pipes"					).setLocalItemName("Quadruple "						, " Pipe"							)	.setMaterialStats(U *12)		.setCondition(PIPES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER).aspects(TC.ITER, 2),
	pipeNonuple					= create("pipeNonuple"					).setCategoryName("Nonuple Pipes"					).setLocalItemName("Nonuple "						, " Pipe"							)	.setMaterialStats(U * 9)		.setCondition(PIPES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER).aspects(TC.ITER, 2),
	pipeRestrictiveTiny			= create("pipeRestrictiveTiny"			).setCategoryName("Tiny Restrictive Pipes"			).setLocalItemName("Tiny Restrictive "				, " Pipe"							)	.setMaterialStats(U2   )		.setCondition(PIPES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE).aspects(TC.ITER, 1),
	pipeRestrictiveSmall		= create("pipeRestrictiveSmall"			).setCategoryName("Small Restrictive Pipes"			).setLocalItemName("Small Restrictive "				, " Pipe"							)	.setMaterialStats(U    )		.setCondition(PIPES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE).aspects(TC.ITER, 1),
	pipeRestrictiveMedium		= create("pipeRestrictiveMedium"		).setCategoryName("Medium Restrictive Pipes"		).setLocalItemName("Medium Restrictive "			, " Pipe"							)	.setMaterialStats(U * 3)		.setCondition(PIPES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE).aspects(TC.ITER, 1),
	pipeRestrictiveLarge		= create("pipeRestrictiveLarge"			).setCategoryName("Large Restrictive Pipes"			).setLocalItemName("Large Restrictive "				, " Pipe"							)	.setMaterialStats(U * 6)		.setCondition(PIPES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE).aspects(TC.ITER, 2),
	pipeRestrictiveHuge			= create("pipeRestrictiveHuge"			).setCategoryName("Huge Restrictive Pipes"			).setLocalItemName("Huge Restrictive "				, " Pipe"							)	.setMaterialStats(U *12)		.setCondition(PIPES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE).aspects(TC.ITER, 2),
	pipe						= create("pipe"							).setCategoryName("Pipes"							).setLocalItemName(""								, " Pipe"							)									.setCondition(PIPES)																						.add().aspects(TC.ITER, 1),
	
	wireGt16					= create("wireGt16"						).setCategoryName("16x Wires"						).setLocalItemName("16x "							, " Wire"							)	.setMaterialStats(U * 8)		.setCondition(WIRES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER).setMinStacksize( 2).aspects(TC.ELECTRUM, 1),
	wireGt12					= create("wireGt12"						).setCategoryName("12x Wires"						).setLocalItemName("12x "							, " Wire"							)	.setMaterialStats(U * 6)		.setCondition(WIRES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER).setMinStacksize( 2).aspects(TC.ELECTRUM, 1),
	wireGt08					= create("wireGt08"						).setCategoryName("8x Wires"						).setLocalItemName("8x "							, " Wire"							)	.setMaterialStats(U * 4)		.setCondition(WIRES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER).setMinStacksize( 2).aspects(TC.ELECTRUM, 1),
	wireGt04					= create("wireGt04"						).setCategoryName("4x Wires"						).setLocalItemName("4x "							, " Wire"							)	.setMaterialStats(U * 2)		.setCondition(WIRES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER).setMinStacksize( 4).aspects(TC.ELECTRUM, 1),
	wireGt02					= create("wireGt02"						).setCategoryName("2x Wires"						).setLocalItemName("2x "							, " Wire"							)	.setMaterialStats(U    )		.setCondition(WIRES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER).setMinStacksize( 8).aspects(TC.ELECTRUM, 1),
	wireGt01					= create("wireGt01"						).setCategoryName("1x Wires"						).setLocalItemName("1x "							, " Wire"							)	.setMaterialStats(U2   )		.setCondition(WIRES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER).setMinStacksize(16).aspects(TC.ELECTRUM, 1),
	
	cableGt12					= create("cableGt12"					).setCategoryName("12x Cables"						).setLocalItemName("12x "							, " Cable"							)	.setMaterialStats(U * 6)		.setCondition(WIRES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE).setMinStacksize( 2).aspects(TC.ELECTRUM, 1),
	cableGt08					= create("cableGt08"					).setCategoryName("8x Cables"						).setLocalItemName("8x "							, " Cable"							)	.setMaterialStats(U * 4)		.setCondition(WIRES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE).setMinStacksize( 2).aspects(TC.ELECTRUM, 1),
	cableGt04					= create("cableGt04"					).setCategoryName("4x Cables"						).setLocalItemName("4x "							, " Cable"							)	.setMaterialStats(U * 2)		.setCondition(WIRES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE).setMinStacksize( 4).aspects(TC.ELECTRUM, 1),
	cableGt02					= create("cableGt02"					).setCategoryName("2x Cables"						).setLocalItemName("2x "							, " Cable"							)	.setMaterialStats(U    )		.setCondition(WIRES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE).setMinStacksize( 8).aspects(TC.ELECTRUM, 1),
	cableGt01					= create("cableGt01"					).setCategoryName("1x Cables"						).setLocalItemName("1x "							, " Cable"							)	.setMaterialStats(U2   )		.setCondition(WIRES)																						.add(UNIFICATABLE, BURNABLE, UNIFICATABLE_RECIPES, RECYCLABLE, SIMPLIFIABLE).setMinStacksize(16).aspects(TC.ELECTRUM, 1),
	
	crateGtGem					= create("crateGtGem"					).setCategoryName("Crates of Gems"					).setLocalItemName("Crate of "						, " Gems"							)	.setMaterialStats(U *16)		.setCondition(gem)																							.add(UNIFICATABLE, BURNABLE, IS_CONTAINER, TOOLTIP_MATERIAL).setStacksize(64).aspects(TC.ITER, 1, TC.VITREUS	, 3), // consisting out of 16 Gems.
	crateGtDust					= create("crateGtDust"					).setCategoryName("Crates of Dust"					).setLocalItemName("Crate of "						, " Dusts"							)	.setMaterialStats(U *16)		.setCondition(dust)																							.add(UNIFICATABLE, BURNABLE, IS_CONTAINER, TOOLTIP_MATERIAL).setStacksize(64).aspects(TC.ITER, 1, TC.PERDITIO	, 3), // consisting out of 16 Dusts.
	crateGtIngot				= create("crateGtIngot"					).setCategoryName("Crates of Ingots"				).setLocalItemName("Crate of "						, " Ingots"							)	.setMaterialStats(U *16)		.setCondition(ingot)																						.add(UNIFICATABLE, BURNABLE, IS_CONTAINER, TOOLTIP_MATERIAL).setStacksize(64).aspects(TC.ITER, 1, TC.METALLUM	, 3), // consisting out of 16 Ingots.
	crateGtPlate				= create("crateGtPlate"					).setCategoryName("Crates of Plates"				).setLocalItemName("Crate of "						, " Plates"							)	.setMaterialStats(U *16)		.setCondition(plate)																						.add(UNIFICATABLE, BURNABLE, IS_CONTAINER, TOOLTIP_MATERIAL).setStacksize(64).aspects(TC.ITER, 1, TC.FABRICO	, 3), // consisting out of 16 Plates.
	crateGtPlateGem				= create("crateGtPlateGem"				).setCategoryName("Crates of Gem Plates"			).setLocalItemName("Crate of "						, " Gem Plates"						)	.setMaterialStats(U *16)		.setCondition(plateGem)																						.add(UNIFICATABLE, BURNABLE, IS_CONTAINER, TOOLTIP_MATERIAL).setStacksize(64).aspects(TC.ITER, 1, TC.FABRICO	, 3), // consisting out of 16 Plates.
	
	blockGem					= create("blockGem"						).setCategoryName("Blocks of Gems"					).setLocalItemName("Block of "						, ""								)	.setMaterialStats(U * 9)		.setCondition(gem)																							.add(BLOCK_BASED, UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL, GEM_BASED).setStacksize(64).aspects(TC.VITREUS		, 3), // To finally get rid of the messy and unreliable Storage Block Code.
	blockDust					= create("blockDust"					).setCategoryName("Blocks of Dusts"					).setLocalItemName("Block of "						, " Dust"							)	.setMaterialStats(U * 9)		.setCondition(dust)																							.add(BLOCK_BASED, UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL, DUST_BASED).setStacksize(64).aspects(TC.PERDITIO	, 3), // To finally get rid of the messy and unreliable Storage Block Code.
	blockIngot					= create("blockIngot"					).setCategoryName("Blocks of Ingots"				).setLocalItemName("Block of "						, " Ingots"							)	.setMaterialStats(U * 9)		.setCondition(ingot)																						.add(BLOCK_BASED, UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL, INGOT_BASED).setStacksize(64).aspects(TC.METALLUM	, 3), // To finally get rid of the messy and unreliable Storage Block Code.
	blockPlate					= create("blockPlate"					).setCategoryName("Blocks of Plates"				).setLocalItemName("Block of "						, " Plates"							)	.setMaterialStats(U * 9)		.setCondition(plate)																						.add(BLOCK_BASED, UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).setStacksize(64).aspects(TC.FABRICO					, 3), // To finally get rid of the messy and unreliable Storage Block Code.
	blockPlateGem				= create("blockPlateGem"				).setCategoryName("Blocks of Gem Plates"			).setLocalItemName("Block of "						, " Gem Plates"						)	.setMaterialStats(U * 9)		.setCondition(plateGem)																						.add(BLOCK_BASED, UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).setStacksize(64).aspects(TC.FABRICO					, 3), // To finally get rid of the messy and unreliable Storage Block Code.
	blockSolid					= create("blockSolid"					).setCategoryName("Blocks of Cast Metal"			).setLocalItemName("Block of solid "				, ""								)	.setMaterialStats(U * 9)		.setCondition(blockIngot)																					.add(BLOCK_BASED, UNIFICATABLE, BURNABLE, RECYCLABLE, SIMPLIFIABLE, SCANNABLE, EXTRUDER_FODDER, TOOLTIP_MATERIAL).setStacksize(64).aspects(TC.METALLUM				, 5), // To finally get rid of the messy and unreliable Storage Block Code.
	
	orebush						= create("orebush"						).setCategoryName("Ore Bushes"						).setLocalItemName(""								, " Bush"							)									.setCondition(PLANTS)																						.add(TD.Creative.HIDDEN, PLANT_DROP).setMinStacksize(16).aspects(TC.HERBA, 1),
	oreberry					= create("oreberry"						).setCategoryName("Ore Berries"						).setLocalItemName(""								, " Berry"							)	.setMaterialStats(U9   )		.setCondition(PLANTS)																						.add(TD.Creative.HIDDEN, UNIFICATABLE, BURNABLE, RECYCLABLE, PLANT_DROP).setMinStacksize(16).aspects(TC.HERBA, 1),
	
	plantGtBerry				= create("plantGtBerry"					).setCategoryName("Berries"							).setLocalItemName(""								, " Berry"							)	.setMaterialStats(U9   )		.setCondition(PLANTS)																						.add(TD.Creative.HIDDEN, UNIFICATABLE, BURNABLE, RECYCLABLE, PLANT_DROP).setMinStacksize(16).aspects(TC.MESSIS, 1),
	plantGtTwig					= create("plantGtTwig"					).setCategoryName("Twigs"							).setLocalItemName(""								, " Twig"							)	.setMaterialStats(U9   )		.setCondition(PLANTS)																						.add(TD.Creative.HIDDEN, UNIFICATABLE, BURNABLE, RECYCLABLE, PLANT_DROP).setMinStacksize(16).aspects(TC.ARBOR, 1),
	plantGtFiber				= create("plantGtFiber"					).setCategoryName("Fibers"							).setLocalItemName("Raw "							, " Fiber"							)	.setMaterialStats(U9   )		.setCondition(PLANTS)																						.add(TD.Creative.HIDDEN, UNIFICATABLE, BURNABLE, RECYCLABLE, PLANT_DROP).setMinStacksize(16).aspects(TC.MESSIS, 1),
	plantGtWart					= create("plantGtWart"					).setCategoryName("Warts"							).setLocalItemName(""								, " Wart"							)	.setMaterialStats(U4   )		.setCondition(PLANTS)																						.add(TD.Creative.HIDDEN, UNIFICATABLE, BURNABLE, RECYCLABLE, PLANT_DROP).setMinStacksize(16).aspects(TC.HERBA, 1),
	plantGtBlossom				= create("plantGtBlossom"				).setCategoryName("Blossoms"						).setLocalItemName(""								, " Blossom"						)	.setMaterialStats(U9   )		.setCondition(PLANTS)																						.add(TD.Creative.HIDDEN, UNIFICATABLE, BURNABLE, RECYCLABLE, PLANT_DROP).setMinStacksize(16).aspects(TC.HERBA, 1),
	
	compressedCobblestone		= create("compressedCobblestone"		).setCategoryName("9^X Compressed Cobblestones"		).setLocalItemName(""								, ""								)									.add(),
	compressedStone				= create("compressedStone"				).setCategoryName("9^X Compressed Stones"			).setLocalItemName(""								, ""								)									.add(),
	compressedDirt				= create("compressedDirt"				).setCategoryName("9^X Compressed Dirt"				).setLocalItemName(""								, ""								)									.add(),
	compressedGravel			= create("compressedGravel"				).setCategoryName("9^X Compressed Gravel"			).setLocalItemName(""								, ""								)									.add(),
	compressedSand				= create("compressedSand"				).setCategoryName("9^X Compressed Sand"				).setLocalItemName(""								, ""								)									.add(),
	
	blockBamboo					= create("blockBamboo"					).setCategoryName("Bamboo Blocks"					).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, BLOCK_BASED),
	blockGlass					= create("blockGlass"					).setCategoryName("Glass Blocks"					).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, BLOCK_BASED),
	blockWool					= create("blockWool"					).setCategoryName("Wool Blocks"						).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, BLOCK_BASED),
	block_						= create("block_"						).setCategoryName("Random Blocks"					).setLocalItemName(""								, ""								)									.add(BLOCK_BASED, NO_PREFIX_FILTERING), // IGNORE
	block						= create("block"						).setCategoryName("Random Blocks"					).setLocalItemName(""								, ""								)									.add(BLOCK_BASED, NO_PREFIX_FILTERING), // Storage Block consisting out of 9 Ingots/Gems/Dusts. Introduced by CovertJaguar, abused by too many people, and then deprecated by me, by adding a bunch of more detailed Prefixes, to finally get rid of the messy an unreliable Storage Block Code.
	
	item_						= create("item_"						).setCategoryName("Items"							).setLocalItemName(""								, ""								)									.add(NO_PREFIX_FILTERING), // IGNORE
	item						= create("item"							).setCategoryName("Items"							).setLocalItemName(""								, ""								)									.add(NO_PREFIX_FILTERING), // Random Item. Introduced by Alblaka
	
	glass						= create("glass"						).setCategoryName("Glasses"							).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, UNIFICATABLE_RECIPES),
	paneGlass					= create("paneGlass"					).setCategoryName("Glass Panes"						).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, BLOCK_BASED),
	stainedClay					= create("stainedClay"					).setCategoryName("Stained Clays"					).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, BLOCK_BASED), // Used for the 16 colors of Stained Clay. Introduced by Forge
	
	craftingTool				= create("craftingTool"					).setCategoryName("Crafting Tools"					).setLocalItemName(""								, ""								)									.add(TOOL_ALIKE), // Special Prefix used mainly for the Crafting Handler.
	crafting					= create("crafting"						).setCategoryName("Crafting Ingredients"			).setLocalItemName(""								, ""								)									.add(NO_PREFIX_FILTERING), // Special Prefix used mainly for the Crafting Handler.
	craft						= create("craft"						).setCategoryName("Crafting Stuff?"					).setLocalItemName(""								, ""								)									.add(), // Special Prefix used mainly for the Crafting Handler.
	
	slab						= create("slab"							).setCategoryName("Slabs"							).setLocalItemName(""								, ""								)									.add(BLOCK_BASED), // Prefix used for Slabs. Usually as "slabWood" or "slabStone". Introduced by SirSengir
	stair						= create("stair"						).setCategoryName("Stairs"							).setLocalItemName(""								, ""								)									.add(BLOCK_BASED), // Prefix used for Stairs. Usually as "stairWood" or "stairStone". Introduced by SirSengir
	fence						= create("fence"						).setCategoryName("Fences"							).setLocalItemName(""								, ""								)									.add(), // Prefix used for Fences. Usually as "fenceWood". Introduced by Forge
	
	treeSapling					= create("treeSapling"					).setCategoryName("Saplings"						).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, BLOCK_BASED).addIdenticalNames("sapling").setMinStacksize(16), // Prefix for Saplings.
	treeLeaves					= create("treeLeaves"					).setCategoryName("Leaves"							).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, BLOCK_BASED).addIdenticalNames("leaves").setMinStacksize(16), // Prefix for Leaves.
	tree						= create("tree"							).setCategoryName("Tree Parts"						).setLocalItemName(""								, ""								)									.add(), // Prefix for Tree Parts.
	log							= create("log"							).setCategoryName("Logs"							).setLocalItemName(""								, ""								)									.add(BLOCK_BASED), // Prefix used for Logs. Usually as "logWood". Introduced by Eloraam
	beam						= create("beam"							).setCategoryName("Beams"							).setLocalItemName(""								, ""								)									.add(BLOCK_BASED), // Prefix used for Beams.  Usually as "beamWood".
	plank						= create("plank"						).setCategoryName("Planks"							).setLocalItemName(""								, ""								)									.add(BLOCK_BASED).setMinStacksize(16), // Prefix for Planks. Usually "plankWood". Introduced by Eloraam
	
	stoneCobble					= create("stoneCobble"					).setCategoryName("Cobblestones"					).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, BLOCK_BASED											).aspects(TC.TERRA, 1), // Cobblestone Prefix for all Cobblestones.
	stoneSmooth					= create("stoneSmooth"					).setCategoryName("Smoothstones"					).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, BLOCK_BASED											).aspects(TC.TERRA, 1), // Smoothstone Prefix.
	stoneMossyBricks			= create("stoneMossyBricks"				).setCategoryName("mossy Stone Bricks"				).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, BLOCK_BASED											).aspects(TC.TERRA, 1).addIdenticalNames("stoneBricksMossy"), // Mossy Stone Bricks.
	stoneMossy					= create("stoneMossy"					).setCategoryName("Mossy Stones"					).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, BLOCK_BASED											).aspects(TC.TERRA, 1), // Mossy Cobble.
	stoneBricks					= create("stoneBricks"					).setCategoryName("Stone Bricks"					).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, BLOCK_BASED											).aspects(TC.TERRA, 1).addIdenticalNames("stoneBrick", "stonebrick"), // Stone Bricks.
	stoneCracked				= create("stoneCracked"					).setCategoryName("Cracked Stones"					).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, BLOCK_BASED											).aspects(TC.TERRA, 1), // Cracked Bricks.
	stoneChiseled				= create("stoneChiseled"				).setCategoryName("Chiseled Stones"					).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, BLOCK_BASED											).aspects(TC.TERRA, 1), // Chiseled Stone.
	stonePolished				= create("stonePolished"				).setCategoryName("Polished Stones"					).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, BLOCK_BASED											).aspects(TC.TERRA, 1), // Polished Stone.
	stone						= create("stone"						).setCategoryName("Stones"							).setLocalItemName(""								, ""								)									.add(MATERIAL_BASED, SELF_REFERENCING, BLOCK_BASED, UNIFICATABLE_RECIPES	).aspects(TC.TERRA, 1), // Prefix to determine which kind of Rock this is.
	cobblestone					= create("cobblestone"					).setCategoryName("Cobblestones"					).setLocalItemName(""								, ""								)									.add(MATERIAL_BASED, SELF_REFERENCING, BLOCK_BASED							).aspects(TC.TERRA, 1),
	rock						= create("rock"							).setCategoryName("Rocks"							).setLocalItemName(""								, ""								)									.add(MATERIAL_BASED, SELF_REFERENCING, BLOCK_BASED, UNIFICATABLE_RECIPES	).aspects(TC.TERRA, 1), // Prefix to determine which kind of Rock this is.
	
	record						= create("record"						).setCategoryName("Records"							).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING).setStacksize(64).aspects(TC.SENSUS, 4),
	scraps						= create("scraps"						).setCategoryName("Scraps"							).setLocalItemName(""								, ""								)									.add(UNIFICATABLE, MATERIAL_BASED),
	scrap						= create("scrap"						).setCategoryName("Scraps"							).setLocalItemName(""								, ""								)									.add(),
	
	book						= create("book"							).setCategoryName("Books"							).setLocalItemName(""								, ""								)									.add(), // Used for Books of any kind.
	paper						= create("paper"						).setCategoryName("Papers"							).setLocalItemName(""								, ""								)									.add(), // Used for Papers of any kind.
	dye							= create("dye"							).setCategoryName("Dyes"							).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING), // Used for the 16 dyes. Introduced by Eloraam
	dyeMixable					= create("dyeMixable"					).setCategoryName("Mixable Dyes"					).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING), // Used for the dyes that can be mixed together.
	dyeCeramic					= create("dyeCeramic"					).setCategoryName("Ceramic Dyes"					).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING), // Used for the MFR dyes.
	
	/* Electric Components.
	 * 
	 * usual Materials for this are:
	 * Primitive (Tier 1)
	 * Basic (Tier 2) as used by UE as well : IC2 Circuit and RE-Battery
	 * Good (Tier 3)
	 * Advanced (Tier 4) as used by UE as well : Advanced Circuit, Advanced Battery and Lithium Battery
	 * Data (Tier 5) : Data Storage Circuit
	 * Elite (Tier 6) as used by UE as well : Energy Crystal and Data Control Circuit
	 * Master (Tier 7) : Energy Flow Circuit and Lapotron Crystal
	 * Ultimate (Tier 8) : Data Orb and Lapotronic Energy Orb
	 * Infinite (Cheaty)
	 */
	batterySingleuse			= create("batterySingleuse"				).setCategoryName("Single Use Batteries"			).setLocalItemName(""								, ""								)									.add(MATERIAL_BASED).aspects(TC.ELECTRUM, 2),
	battery						= create("battery"						).setCategoryName("Reusable Batteries"				).setLocalItemName(""								, ""								)									.add(MATERIAL_BASED).aspects(TC.ELECTRUM, 1), // Introduced by Calclavia
	circuit						= create("circuit"						).setCategoryName("Circuits"						).setLocalItemName(""								, ""								)									.add(MATERIAL_BASED).aspects(TC.COGNITO, 1), // Introduced by Calclavia
	computer					= create("computer"						).setCategoryName("Computers"						).setLocalItemName(""								, ""								)									.add(MATERIAL_BASED).aspects(TC.COGNITO, 4), // A whole Computer.
	
	// random known prefixes without special abilities.
	sand						= unused("sand"							).setCategoryName("Sands"							).setLocalItemName(""								, ""								)									.add(SELF_REFERENCING, BLOCK_BASED),
	wire						= unused("wire"							).setCategoryName("Wires"							).setLocalItemName(""								, ""								)									.add(UNIFICATABLE_RECIPES).aspects(TC.ELECTRUM, 1),
	lamp						= unused("lamp"							).setCategoryName("Lamps"),
	cloth						= unused("cloth"						).setCategoryName("Cloth"),
	fabric						= unused("fabric"						).setCategoryName("Fabric"),
	quartz						= unused("quartz"						).setCategoryName("Quartzes"),
	part						= unused("part"							).setCategoryName("Parts"), // partBasicCircuit partAdvancedCircuit partPhotocell partMotor
	torch						= unused("torch"						).setCategoryName("Torches"),
	skull						= unused("skull"						).setCategoryName("Skulls"),
	plating						= unused("plating"						).setCategoryName("Platings"),
	dinosaur					= unused("dinosaur"						).setCategoryName("Dinosaurs"),
	travelgear					= unused("travelgear"					).setCategoryName("Travel Gear"),
	bauble						= unused("bauble"						).setCategoryName("Baubles"),
	grafter						= unused("grafter"						).setCategoryName("Grafters"),
	scoop						= unused("scoop"						).setCategoryName("Scoops"),
	frame						= unused("frame"						).setCategoryName("Frames").aspects(TC.FABRICO, 1),
	tome						= unused("tome"							).setCategoryName("Tomes"),
	junk						= unused("junk"							).setCategoryName("Junk"),
	bee							= unused("bee"							).setCategoryName("Bees"),
	rod							= unused("rod"							).setCategoryName("Rods"),
	dirt						= unused("dirt"							).setCategoryName("Dirts"),
	grass						= unused("grass"						).setCategoryName("Grasses"),
	gravel						= unused("gravel"						).setCategoryName("Gravels"),
	mushroom					= unused("mushroom"						).setCategoryName("Mushrooms"),
	wood						= unused("wood"							).setCategoryName("Woods"), // Introduced by Eloraam
	drop						= unused("drop"							).setCategoryName("Drops"),
	fuel						= unused("fuel"							).setCategoryName("Fuels"),
	panel						= unused("panel"						).setCategoryName("Panels"),
	brick						= unused("brick"						).setCategoryName("Bricks"),
	seed						= unused("seed"							).setCategoryName("Seeds"),
	reed						= unused("reed"							).setCategoryName("Reeds"),
	sheetDouble					= unused("sheetDouble"					).setCategoryName("2x Sheets"),
	sheet						= unused("sheet"						).setCategoryName("Sheets"),
	crop						= unused("crop"							).setCategoryName("Crops"),
	plant						= unused("plant"						).setCategoryName("Plants"),
	coin						= unused("coin"							).setCategoryName("Coins"),
	lumar						= unused("lumar"						).setCategoryName("Lumars"),
	ground						= unused("ground"						).setCategoryName("Grounded Stuff"),
	cable						= unused("cable"						).setCategoryName("Cables").aspects(TC.ELECTRUM, 1),
	component					= unused("component"					).setCategoryName("Components"),
	pole						= unused("pole"							).setCategoryName("Poles"),
	desert						= unused("desert"						).setCategoryName("Desert Stuff"),
	jungle						= unused("jungle"						).setCategoryName("Jungle Stuff"),
	savanna						= unused("savanna"						).setCategoryName("Savanna Stuff"),
	beach						= unused("beach"						).setCategoryName("Beach Stuff"),
	forest						= unused("forest"						).setCategoryName("Forest Stuff"),
	mountain					= unused("mountain"						).setCategoryName("Mountain Stuff"),
	plains						= unused("plains"						).setCategoryName("Plains Stuff"),
	epiphyte					= unused("epiphyte"						).setCategoryName("Epiphyte Stuff"),
	water						= unused("water"						).setCategoryName("Water Stuff"),
	river						= unused("river"						).setCategoryName("River Stuff"),
	ocean						= unused("ocean"						).setCategoryName("Ocean Stuff"),
	hanging						= unused("hanging"						).setCategoryName("Hanging Stuff"),
	floating					= unused("floating"						).setCategoryName("Floating Stuff"),
	wetlands					= unused("wetlands"						).setCategoryName("Wetland Stuff"),
	fern						= unused("fern"							).setCategoryName("Ferns"),
	vine						= unused("vine"							).setCategoryName("Vines"),
	fungus						= unused("fungus"						).setCategoryName("Fungi"),
	cactus						= unused("cactus"						).setCategoryName("Cacti"),
	bud							= unused("bud"							).setCategoryName("Buds"),
	immersed					= unused("immersed"						).setCategoryName("Immersed Stuff"),
	bamboo						= unused("bamboo"						).setCategoryName("Bamboo Stuff"),
	cones						= unused("cones"						).setCategoryName("Cones"),
	consumable					= unused("consumable"					).setCategoryName("Consumables"),
	leafy						= unused("leafy"						).setCategoryName("Leafy Stuff"),
	leaf						= unused("leaf"							).setCategoryName("Leaf Stuff"),
	shrub						= unused("shrub"						).setCategoryName("Shrubs"),
	berrybush					= unused("berrybush"					).setCategoryName("Berry Bushes"),
	wax							= unused("wax"							).setCategoryName("Waxes"),
	wall						= unused("wall"							).setCategoryName("Walls"),
	tube						= unused("tube"							).setCategoryName("Tubes"),
	list						= unused("list"							).setCategoryName("Lists").add(NO_PREFIX_FILTERING),
	food						= unused("food"							).setCategoryName("Foods").add(NO_PREFIX_FILTERING),
	gear						= unused("gear"							).setCategoryName("Gears"), // Introduced by SirSengir
	coral						= unused("coral"						).setCategoryName("Corals"),
	flower						= unused("flower"						).setCategoryName("Flowers"),
	storage						= unused("storage"						).setCategoryName("Storages"),
	material					= unused("material"						).setCategoryName("Materials").add(NO_PREFIX_FILTERING),
	plasma						= unused("plasma"						).setCategoryName("Plasmas"),
	element						= unused("element"						).setCategoryName("Elements"),
	molecule					= unused("molecule"						).setCategoryName("Molecules"),
	wafer						= unused("wafer"						).setCategoryName("Wafers"),
	orb							= unused("orb"							).setCategoryName("Orbs"),
	handle						= unused("handle"						).setCategoryName("Handles"),
	blade						= unused("blade"						).setCategoryName("Blades"),
	head						= unused("head"							).setCategoryName("Heads"),
	motor						= unused("motor"						).setCategoryName("Motors"),
	bowl						= unused("bowl"							).setCategoryName("Bowls"),
	bit							= unused("bit"							).setCategoryName("Bits"),
	shears						= unused("shears"						).setCategoryName("Shears"),
	turbine						= unused("turbine"						).setCategoryName("Turbines"),
	fertilizer					= unused("fertilizer"					).setCategoryName("Fertilizers"),
	chest						= unused("chest"						).setCategoryName("Chests"),
	raw							= unused("raw"							).setCategoryName("Raw Things"),
	stainedGlass				= unused("stainedGlass"					).setCategoryName("Stained Glasses"),
	mystic						= unused("mystic"						).setCategoryName("Mystic Stuff"),
	mana						= unused("mana"							).setCategoryName("Mana Stuff"),
	rune						= unused("rune"							).setCategoryName("Runes"),
	petal						= unused("petal"						).setCategoryName("Petals"),
	pearl						= unused("pearl"						).setCategoryName("Pearls"),
	powder						= unused("powder"						).setCategoryName("Powders"),
	soulsand					= unused("soulsand"						).setCategoryName("Soulsands"),
	obsidian					= unused("obsidian"						).setCategoryName("Obsidians"),
	glowstone					= unused("glowstone"					).setCategoryName("Glowstones"),
	beans						= unused("beans"						).setCategoryName("Beans"),
	essence						= unused("essence"						).setCategoryName("Essences"),
	alloy						= unused("alloy"						).setCategoryName("Alloys"),
	cooking						= unused("cooking"						).setCategoryName("Cooked Things"),
	gate						= unused("gate"							).setCategoryName("Gates"),
	ladder						= unused("ladder"						).setCategoryName("Ladders"),
	door						= unused("door"							).setCategoryName("Doors"),
	trapdoor					= unused("trapdoor"						).setCategoryName("Trapdoors"),
	elven						= unused("elven"						).setCategoryName("Elven Stuff"),
	reactor						= unused("reactor"						).setCategoryName("Reactors"),
	mffs						= unused("mffs"							).setCategoryName("MFFS"),
	projred						= unused("projred"						).setCategoryName("Project Red"),
	ganys						= unused("ganys"						).setCategoryName("Ganys Stuff"),
	liquid						= unused("liquid"						).setCategoryName("Liquids"),
	chipset						= unused("chipset"						).setCategoryName("Chipsets"),
	boule						= unused("boule"						).setCategoryName("Boules"),
	bars						= unused("bars"							).setCategoryName("Bars"),
	bar							= unused("bar"							).setCategoryName("Bars");
	
	static {
		crushed		.addListener(new OreDictListenerItem_Washing(crushedPurified, 2, nugget, gemChipped, crushedPurifiedTiny, crushedPurifiedTiny, dustTiny, dustTiny));
		dustImpure	.addListener(new OreDictListenerItem_Washing(dust, 3, dustTiny));
		dustPure	.addListener(new OreDictListenerItem_Washing(dust, 4, dustTiny));
		dustRefined	.addListener(new OreDictListenerItem_Washing(dust, 5, dustTiny));
		
		bottle.mContainerItem = ST.make(Items.glass_bottle, 1, 0);
		
		ingotHot.mHeatDamage = 3.0F;
		
		crushed.addFamiliarPrefix(crushedTiny);
		crushedTiny.addFamiliarPrefix(crushed);
		crushedPurified.addFamiliarPrefix(crushedPurifiedTiny);
		crushedPurifiedTiny.addFamiliarPrefix(crushedPurified);
		crushedCentrifuged.addFamiliarPrefix(crushedCentrifugedTiny);
		crushedCentrifugedTiny.addFamiliarPrefix(crushedCentrifuged);
		
		dust.addFamiliarPrefix(dustTiny);
		dust.addFamiliarPrefix(dustSmall);
		dust.addFamiliarPrefix(dustDiv72);
		dust.addFamiliarPrefix(blockDust);
		dustTiny.addFamiliarPrefix(dust);
		dustTiny.addFamiliarPrefix(dustSmall);
		dustTiny.addFamiliarPrefix(dustDiv72);
		dustTiny.addFamiliarPrefix(blockDust);
		dustSmall.addFamiliarPrefix(dust);
		dustSmall.addFamiliarPrefix(dustTiny);
		dustSmall.addFamiliarPrefix(dustDiv72);
		dustSmall.addFamiliarPrefix(blockDust);
		dustDiv72.addFamiliarPrefix(dust);
		dustDiv72.addFamiliarPrefix(dustTiny);
		dustDiv72.addFamiliarPrefix(dustSmall);
		dustDiv72.addFamiliarPrefix(blockDust);
		blockDust.addFamiliarPrefix(dust);
		blockDust.addFamiliarPrefix(dustTiny);
		blockDust.addFamiliarPrefix(dustSmall);
		blockDust.addFamiliarPrefix(dustDiv72);
		
		ingot.addFamiliarPrefix(nugget);
		ingot.addFamiliarPrefix(chunkGt);
		ingot.addFamiliarPrefix(blockIngot);
		nugget.addFamiliarPrefix(ingot);
		nugget.addFamiliarPrefix(chunkGt);
		nugget.addFamiliarPrefix(blockIngot);
		chunkGt.addFamiliarPrefix(nugget);
		chunkGt.addFamiliarPrefix(ingot);
		chunkGt.addFamiliarPrefix(blockIngot);
		blockIngot.addFamiliarPrefix(nugget);
		blockIngot.addFamiliarPrefix(ingot);
		blockIngot.addFamiliarPrefix(chunkGt);
		
		for (OreDictPrefix tPrefix1 : OreDictPrefix.VALUES) if (tPrefix1.mNameInternal.startsWith("ore"		)) for (OreDictPrefix tPrefix2 : OreDictPrefix.VALUES) if (tPrefix2.mNameInternal.startsWith("ore"		)) tPrefix1.addFamiliarPrefix(tPrefix2);
		for (OreDictPrefix tPrefix1 : OreDictPrefix.VALUES) if (tPrefix1.mNameInternal.startsWith("pipe"	)) for (OreDictPrefix tPrefix2 : OreDictPrefix.VALUES) if (tPrefix2.mNameInternal.startsWith("pipe"		)) tPrefix1.addFamiliarPrefix(tPrefix2);
		for (OreDictPrefix tPrefix1 : OreDictPrefix.VALUES) if (tPrefix1.mNameInternal.startsWith("wireGt"	)) for (OreDictPrefix tPrefix2 : OreDictPrefix.VALUES) if (tPrefix2.mNameInternal.startsWith("wireGt"	)) tPrefix1.addFamiliarPrefix(tPrefix2);
		for (OreDictPrefix tPrefix1 : OreDictPrefix.VALUES) if (tPrefix1.mNameInternal.startsWith("cableGt"	)) for (OreDictPrefix tPrefix2 : OreDictPrefix.VALUES) if (tPrefix2.mNameInternal.startsWith("cableGt"	)) tPrefix1.addFamiliarPrefix(tPrefix2);
		
		// Items which are already there in vanilla MC and IC2.
		gem					.disableItemGeneration(MT.Coal, MT.Charcoal, MT.NetherStar, MT.Diamond, MT.Emerald, MT.NetherQuartz, MT.EnderPearl, MT.EnderEye, MT.Flint, MT.Lapis);
		dust				.disableItemGeneration(MT.Bone, MT.Redstone, MT.Glowstone, MT.Gunpowder, MT.Sugar, MT.Blaze);
		stick				.disableItemGeneration(MT.Wood, MT.Bone, MT.Blaze);
		ingot				.disableItemGeneration(MT.Fe, MT.Au, MT.NetherBrick);
		nugget				.disableItemGeneration(MT.Au);
		plate				.disableItemGeneration(MT.Paper);
		bucket				.disableItemGeneration(MT.Empty, MT.Water, MT.Lava, MT.Milk);
		bottle				.disableItemGeneration(MT.Empty, MT.Water);
		
		gemChipped			.forceItemGeneration(MT.Ice, MT.NaCl, MT.KCl, MT.ICl, MT.Sugar);
		gemFlawed			.forceItemGeneration(MT.Ice, MT.NaCl, MT.KCl, MT.ICl);
		gem					.forceItemGeneration(MT.Ice, MT.NaCl, MT.KCl, MT.ICl);
		bouleGt				.forceItemGeneration(MT.Si, MT.RedstoneAlloy);
		plateTiny			.forceItemGeneration(MT.Paper);
		
		for (OreDictMaterial tMat : ANY.Glowstone.mToThis) tMat.setPriorityPrefix(OP.dust);
		MT.Electrotine			.setPriorityPrefix(OP.dust);
		MT.Nikolite				.setPriorityPrefix(OP.dust);
		MT.Teslatite			.setPriorityPrefix(OP.dust);
		MT.Redstone				.setPriorityPrefix(OP.dust);
		MT.Si					.setPriorityPrefix(OP.plateGem);
		MT.RedstoneAlloy		.setPriorityPrefix(OP.plateGem);
		
		//-----
		
		pipeRestrictiveTiny.mByProducts		.add(OM.stack(ANY.Steel				, ring.mAmount));
		pipeRestrictiveSmall.mByProducts	.add(OM.stack(ANY.Steel				, ring.mAmount * 2));
		pipeRestrictiveMedium.mByProducts	.add(OM.stack(ANY.Steel				, ring.mAmount * 3));
		pipeRestrictiveLarge.mByProducts	.add(OM.stack(ANY.Steel				, ring.mAmount * 4));
		pipeRestrictiveHuge.mByProducts		.add(OM.stack(ANY.Steel				, ring.mAmount * 5));
		cableGt12.mByProducts				.add(OM.stack(MT.Rubber				, plate.mAmount * 4));
		cableGt08.mByProducts				.add(OM.stack(MT.Rubber				, plate.mAmount * 3));
		cableGt04.mByProducts				.add(OM.stack(MT.Rubber				, plate.mAmount * 2));
		cableGt02.mByProducts				.add(OM.stack(MT.Rubber				, plate.mAmount));
		cableGt01.mByProducts				.add(OM.stack(MT.Rubber				, plate.mAmount));
//		bucket.mByProducts					.add(OM.stack(MT.Fe					, ingot.mAmount * 3));
		cell.mByProducts					.add(OM.stack(MT.Sn					, plateCurved.mAmount));
		bottle.mByProducts					.add(OM.stack(MT.Glass				, U));
		chemtube.mByProducts				.add(OM.stack(MT.Glass				, U3));
		oreBedrock.mByProducts				.add(OM.stack(MT.Bedrock			, dust.mAmount));
		oreAndesite.mByProducts				.add(OM.stack(MT.Andesite			, dust.mAmount));
		oreDiorite.mByProducts				.add(OM.stack(MT.Diorite			, dust.mAmount));
		oreRedgranite.mByProducts			.add(OM.stack(MT.GraniteRed			, dust.mAmount));
		oreBlackgranite.mByProducts			.add(OM.stack(MT.GraniteBlack		, dust.mAmount));
		oreMoon.mByProducts					.add(OM.stack(MT.MoonRock			, dust.mAmount));
		oreMars.mByProducts					.add(OM.stack(MT.MarsRock			, dust.mAmount));
		oreUmberstone.mByProducts			.add(OM.stack(MT.Umber				, dust.mAmount));
		oreBasalt.mByProducts				.add(OM.stack(MT.Basalt				, dust.mAmount));
		oreMarble.mByProducts				.add(OM.stack(MT.Marble				, dust.mAmount));
		oreLimestone.mByProducts			.add(OM.stack(MT.Limestone			, dust.mAmount));
		oreNetherrack.mByProducts			.add(OM.stack(MT.Netherrack			, dust.mAmount));
		oreNether.mByProducts				.add(OM.stack(MT.Netherrack			, dust.mAmount));
		oreEndstone.mByProducts				.add(OM.stack(MT.Endstone			, dust.mAmount));
		oreEnd.mByProducts					.add(OM.stack(MT.Endstone			, dust.mAmount));
		orePoor.mByProducts					.add(OM.stack(MT.Stone				, dust.mAmount * 2));
		oreSmall.mByProducts				.add(OM.stack(MT.Stone				, dust.mAmount * 2));
		oreNormal.mByProducts				.add(OM.stack(MT.Stone				, dust.mAmount * 2));
		oreRich.mByProducts					.add(OM.stack(MT.Stone				, dust.mAmount * 2));
		ore.mByProducts						.add(OM.stack(MT.Stone				, dust.mAmount));
		crushed.mByProducts					.add(OM.stack(MT.Stone				, dust.mAmount));
		toolHeadPickaxeGem.mByProducts		.add(OM.stack(ANY.Steel				, toolHeadPickaxe.mAmount));
		toolHeadDrill.mByProducts			.add(OM.stack(ANY.Steel				, plate.mAmount * 4));
		toolHeadChainsaw.mByProducts		.add(OM.stack(ANY.Steel				, plate.mAmount * 4 + ring.mAmount * 2));
		toolHeadWrench.mByProducts			.add(OM.stack(ANY.Steel				, ring.mAmount + screw.mAmount * 2));
		arrowGtWood.mByProducts				.add(OM.stack(ANY.Wood				, stick.mAmount));
		arrowGtPlastic.mByProducts			.add(OM.stack(MT.Plastic			, stick.mAmount));
		bulletGtSmall.mByProducts			.add(OM.stack(MT.Brass				, ingot.mAmount / 9));
		bulletGtMedium.mByProducts			.add(OM.stack(MT.Brass				, ingot.mAmount / 6));
		bulletGtLarge.mByProducts			.add(OM.stack(MT.Brass				, ingot.mAmount / 3));
		plantGtTwig.mByProducts				.add(OM.stack(ANY.Wood				, stick.mAmount));
	}
}